@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -50,9 +50,9 @@ public:
     SKGObjectModel(SKGDocumentBank* iDocument,
                    const QString& iTable,
                    const QString& iWhereClause,
-                   QObject *parent=NULL,
-                   const QString& iParentAttribute="",
-                   bool iResetOnCreation=true);
+                   QObject *parent = NULL,
+                   const QString& iParentAttribute = "",
+                   bool iResetOnCreation = true);
 
     /**
      * Destructor
@@ -65,7 +65,7 @@ public:
      * @param role the role
      * @return the returned value
      */
-    virtual QVariant data ( const QModelIndex & index, int role = Qt::DisplayRole ) const;
+    virtual QVariant data(const QModelIndex & index, int role = Qt::DisplayRole) const;
 
     /**
      * Sets the role data for the item at index to value. Returns true if successful; otherwise returns false.
@@ -83,7 +83,7 @@ public:
      * @param role the role
      * @return the header data
      */
-    virtual QVariant headerData ( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const;
+    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
 
     /**
      * Returns the item flags for the given index.
@@ -138,43 +138,49 @@ protected Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGObjectModel);
 
-    SKGServices::SKGUnitInfo cacheUnit;
-    bool operationTable;
-    bool recurrentoperationTable;
-    bool trackerTable;
-    bool accountTable;
-    bool unitTable;
-    bool unitvalueTable;
-    bool suboperationTable;
-    bool categoryTable;
-    bool ruleTable;
-    bool interestTable;
-    bool payeeTable;
+    SKGServices::SKGUnitInfo m_cacheUnit;
+    bool m_operationTable;
+    bool m_recurrentoperationTable;
+    bool m_trackerTable;
+    bool m_accountTable;
+    bool m_unitTable;
+    bool m_unitvalueTable;
+    bool m_suboperationTable;
+    bool m_categoryTable;
+    bool m_ruleTable;
+    bool m_interestTable;
+    bool m_payeeTable;
+    bool m_budgetTable;
+    bool m_budgetRuleTable;
 
-    QVariant fontDisabledScheduleColor;
-    QVariant fontFutureOperationsColor;
-    QVariant fontNotValidatedOperationsColor;
-    QVariant fontSubOperationsColor;
-    QVariant fontRedColor;
+    QVariant m_fontDisabledScheduleColor;
+    QVariant m_fontFutureOperationsColor;
+    QVariant m_fontNotValidatedOperationsColor;
+    QVariant m_fontSubOperationsColor;
+    QVariant m_fontRedColor;
 
-    QVariant icon_skrooge_transfer;
-    QVariant icon_skrooge_split;
-    QVariant icon_skrooge_much_more;
-    QVariant icon_skrooge_much_less;
-    QVariant icon_skrooge_more;
-    QVariant icon_skrooge_less;
-    QVariant icon_closed;
-    QVariant icon_imported;
-    QVariant icon_imported_checked;
-    QVariant icon_recurrent;
-    QVariant icon_recurrent_master;
-    QVariant icon_favorite;
-    QVariant icon_category;
-    QVariant icon_category_plus;
-    QVariant icon_category_moins;
-    QVariant icon_search;
-    QVariant icon_update;
-    QVariant icon_alarm;
+    QVariant m_iconTransfer;
+    QVariant m_iconSplit;
+    QVariant m_iconMuchMore;
+    QVariant m_iconMuchLess;
+    QVariant m_iconMore;
+    QVariant m_iconLess;
+    QVariant m_iconClosed;
+    QVariant m_iconImported;
+    QVariant m_iconImportedChecked;
+    QVariant m_iconRecurrent;
+    QVariant m_iconRecurrentMaster;
+    QVariant m_iconFavorite;
+    QVariant m_iconCategory;
+    QVariant m_iconCategoryPlus;
+    QVariant m_iconCategoryMoins;
+    QVariant m_iconSearch;
+    QVariant m_iconUpdate;
+    QVariant m_iconAlarm;
+
+    QVariant m_iconGreen;
+    QVariant m_iconRed;
+    QVariant m_iconAnber;
 };
 
 #endif
