@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,7 +24,6 @@
 #include "skgbankgui_export.h"
 
 #include <QWidget>
-#include <QtDesigner/QDesignerExportWidget>
 
 class SKGDocument;
 class SKGComboBox;
@@ -38,12 +37,12 @@ class SKGBANKGUI_EXPORT SKGPredicatCreator : public QWidget
     /**
      * Text of the predicat
      */
-    Q_PROPERTY( QString text READ text USER true)
+    Q_PROPERTY(QString text READ text USER true)
 
     /**
      * XML description of the predicat
      */
-    Q_PROPERTY( QString xmlDescription READ xmlDescription WRITE setXmlDescription)
+    Q_PROPERTY(QString xmlDescription READ xmlDescription WRITE setXmlDescription)
 
 public:
     /**
@@ -54,8 +53,8 @@ public:
      * @param iSQL to enable sql mode
      * @param iListAtt list of attribute
      */
-    explicit SKGPredicatCreator(QWidget *parent = 0, SKGDocument* document=NULL, const QString& attribute="",
-                                bool iSQL=false, const QStringList& iListAtt=QStringList());
+    explicit SKGPredicatCreator(QWidget *parent = 0, SKGDocument* document = NULL, const QString& attribute = "",
+                                bool iSQL = false, const QStringList& iListAtt = QStringList());
 
     /**
      * Default Destructor
@@ -99,19 +98,19 @@ protected :
      * @param event event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter ( QObject *object, QEvent *event );
+    virtual bool eventFilter(QObject *object, QEvent *event);
 
 private Q_SLOTS:
     void onOperatorChanged();
 
 private:
     Q_DISABLE_COPY(SKGPredicatCreator);
-    bool updateMode;
+    bool m_updateMode;
 
-    SKGComboBox* kOperator;
-    QWidget* kValue1;
-    QWidget* kValue2;
-    SKGComboBox* kAttributes;
+    SKGComboBox* m_kOperator;
+    QWidget* m_kValue1;
+    QWidget* m_kValue2;
+    SKGComboBox* m_kAttributes;
 };
 
 #endif // SKGPREDICATCREATOR_H
