@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,17 +24,18 @@
 #include <qdom.h>
 #include "skgpredicatcreator.h"
 
-SKGProcessCreator::SKGProcessCreator(QWidget* parent): QWidget(parent)
+SKGProcessCreator::SKGProcessCreator(QWidget* parent):
+    QWidget(parent), m_document(NULL)
 {
     ui.setupUi(this);
-    ui.addLineBtn->setIcon( KIcon ( "list-add" ) );
+    ui.addLineBtn->setIcon(KIcon("list-add"));
     // When clicking on the addLine Button, add a new line in the process definition
-    connect(ui.addLineBtn,SIGNAL(clicked(bool)),this,SLOT(addLine()));
+    connect(ui.addLineBtn, SIGNAL(clicked(bool)), this, SLOT(addLine()));
 }
 
 SKGProcessCreator::~SKGProcessCreator()
 {
-
+    m_document = NULL;
 }
 
 SKGPropertyEditor* SKGProcessCreator::addLine()
@@ -43,58 +44,54 @@ SKGPropertyEditor* SKGProcessCreator::addLine()
     SKGPropertyEditor* lineEditor = new SKGPropertyEditor();
     ui.propertyLinesLayout->addWidget(lineEditor);
     // Give the line the appropriate parameters
-    lineEditor->setParameters(document,table,listAtts,listOtherAtts);
+    lineEditor->setParameters(m_document, m_table, m_listAtts, m_listOtherAtts);
     lineEditor->setupWidgets();
     return lineEditor;
 }
 
-void SKGProcessCreator::setParameters(SKGDocument* iDocument, const QString& iTable, const QStringList& iListAttribute,const QStringList& iListOtherAttribute)
+void SKGProcessCreator::setParameters(SKGDocument* iDocument, const QString& iTable, const QStringList& iListAttribute, const QStringList& iListOtherAttribute)
 {
-    document = iDocument;
-    table = iTable;
-    listAtts = iListAttribute;
-    listOtherAtts = iListOtherAttribute;
+    m_document = iDocument;
+    m_table = iTable;
+    m_listAtts = iListAttribute;
+    m_listOtherAtts = iListOtherAttribute;
 }
 
 
 void SKGProcessCreator::setXMLCondition(const QString& iXML)
 {
-    QDomDocument doc ( "SKGML" );
-    doc.setContent ( iXML );
+    QDomDocument doc("SKGML");
+    doc.setContent(iXML);
     QDomElement root = doc.documentElement();
 
     // Remove all existing lines
-    for (int i=0; ui.propertyLinesLayout->count(); i++) {
+    for(int i = 0; ui.propertyLinesLayout->count(); i++) {
         QLayoutItem*line = ui.propertyLinesLayout->takeAt(i);
-        line->widget()->deleteLater();
+        if(line) line->widget()->deleteLater();
     }
     QDomNode l = root.firstChild();
-    while ( !l.isNull() )
-    {
+    while(!l.isNull()) {
         QDomElement elementl = l.toElement();
-        if ( !elementl.isNull() )
-        {
+        if(!elementl.isNull()) {
             //Add new line
             SKGPropertyEditor*line = addLine();
 
             QDomNode n = elementl.firstChild();
-            while ( !n.isNull() )
-            {
+            while(!n.isNull()) {
                 QDomElement element = n.toElement();
-                if ( !element.isNull() )
-                {
-                    QString attribute=element.attribute ( "attribute" );
+                if(!element.isNull()) {
+                    QString attribute = element.attribute("attribute");
 
-                    QDomDocument doc2 ( "SKGML" );
-                    QDomElement root2 = doc2.createElement ( "element" );
-                    doc2.appendChild ( root2 );
-                    root2.setAttribute ( "operator", element.attribute ( "operator" ) );
-                    root2.setAttribute ( "value", element.attribute ( "value" ) );
-                    root2.setAttribute ( "value2", element.attribute ( "value2" ) );
-                    root2.setAttribute ( "att2", element.attribute ( "att2" ) );
-                    root2.setAttribute ( "att2s", element.attribute ( "att2s" ) );
-                    QString xml=doc2.toString();
-                    line->setXMLCondition( SKGPredicatCreator::getTextFromXml ( xml ) );
+                    QDomDocument doc2("SKGML");
+                    QDomElement root2 = doc2.createElement("element");
+                    doc2.appendChild(root2);
+                    root2.setAttribute("operator", element.attribute("operator"));
+                    root2.setAttribute("value", element.attribute("value"));
+                    root2.setAttribute("value2", element.attribute("value2"));
+                    root2.setAttribute("att2", element.attribute("att2"));
+                    root2.setAttribute("att2s", element.attribute("att2s"));
+                    QString xml = doc2.toString();
+                    if(line) line->setXMLCondition(SKGPredicatCreator::getTextFromXml(xml));
                 }
                 n = n.nextSibling();
             }
@@ -141,3 +138,5 @@ QString SKGProcessCreator::getXMLCondition()
 //     return doc.toString();
     return "";
 }
+
+#include "skgprocesscreator.moc"
