@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -26,7 +26,6 @@
 #include "skgbankgui_export.h"
 
 #include <QWidget>
-#include <QtDesigner/QDesignerExportWidget>
 #include "skgpropertyeditor.h"
 
 class SKGDocument;
@@ -55,7 +54,8 @@ public:
      * Set parameters
      * @param iDocument the document
      * @param iTable the table
-     * @param iListAttribute the list of attribute (empty means all attributes supported of the table)
+     * @param iListAttribute the list of attributes (empty means all attributes supported of the table)
+     * @param iListOtherAttribute the list of other attributes (empty means all attributes supported of the table)
      */
     virtual void setParameters(SKGDocument* iDocument, const QString& iTable, const QStringList& iListAttribute = QStringList(), const QStringList& iListOtherAttribute = QStringList());
 
@@ -85,18 +85,18 @@ private:
     Ui::skgprocesscreator_base ui;
 
     // This is the document we are working on (current doc)
-    SKGDocument* document;
+    SKGDocument* m_document;
 
     // This is the table we are using
-    QString table;
+    QString m_table;
 
     // This is the list of main attributes, the ones that can be modified
     // using the search & process plugin
-    QStringList listAtts;
+    QStringList m_listAtts;
 
     // This is the secondary list of attributes, ie the ones that can be
     // used as a reference for modifying main attributes
-    QStringList listOtherAtts;
+    QStringList m_listOtherAtts;
 };
 
 #endif // SKGPROCESSCREATOR_H
