@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -20,76 +20,73 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgpropertyeditor.h"
+#include "skgdocument.h"
+
 #include <QListWidget>
 
-SKGPropertyEditor::SKGPropertyEditor(QWidget* parent): QWidget(parent)
+SKGPropertyEditor::SKGPropertyEditor(QWidget* parent):
+    QWidget(parent), m_document(NULL)
 {
     ui.setupUi(this);
 
-    ui.removeLineButton->setIcon( KIcon ( "list-remove" ) );
+    ui.removeLineButton->setIcon(KIcon("list-remove"));
 
-    listOperations << i18nc("Define a value in a text input","Set value...");
-    listOperations << i18nc("Define an attribute's value using the value of another attribute","From attribute...");
-    listOperations << i18nc("Change the case of a string, as in lowercase, uppercase...","Change case...");
+    m_listOperations << i18nc("Define a value in a text input", "Set value...");
+    m_listOperations << i18nc("Define an attribute's value using the value of another attribute", "From attribute...");
+    m_listOperations << i18nc("Change the case of a string, as in lowercase, uppercase...", "Change case...");
 
-    for ( int i=0 ; i<listOperations.count() ; i++ )
-    {
-        ui.operationSelect->addItem( listOperations.at(i) );
+    for(int i = 0 ; i < m_listOperations.count() ; i++) {
+        ui.operationSelect->addItem(m_listOperations.at(i));
     }
 
-    ui.caseSelect->addItem(i18nc("Change a string to lowercase","lowercase"));
-    ui.caseSelect->addItem(i18nc("Change a string to uppercase","uppercase"));
+    ui.caseSelect->addItem(i18nc("Change a string to lowercase", "lowercase"));
+    ui.caseSelect->addItem(i18nc("Change a string to uppercase", "uppercase"));
 
     // Destroy me when clicking on the button
-    connect(ui.removeLineButton,SIGNAL(clicked(bool)),this,SLOT(deleteLater()));
+    connect(ui.removeLineButton, SIGNAL(clicked(bool)), this, SLOT(deleteLater()));
 
     // Display relevant widgets depending on attributes and operations
-    connect(ui.attributeSelect,SIGNAL(currentIndexChanged(int)),this,SLOT(setupWidgets()));
-    connect(ui.operationSelect,SIGNAL(currentIndexChanged(int)),this,SLOT(setupWidgets()));
-    connect(ui.substringTextBox,SIGNAL(stateChanged(int)),this,SLOT(setupWidgets()));
+    connect(ui.attributeSelect, SIGNAL(currentIndexChanged(int)), this, SLOT(setupWidgets()));
+    connect(ui.operationSelect, SIGNAL(currentIndexChanged(int)), this, SLOT(setupWidgets()));
+    connect(ui.substringTextBox, SIGNAL(stateChanged(int)), this, SLOT(setupWidgets()));
 
 }
 
 SKGPropertyEditor::~SKGPropertyEditor()
 {
-
+    m_document = NULL;
 }
 
 void SKGPropertyEditor::setParameters(SKGDocument* iDocument, const QString& iTable, const QStringList& iEditableAttribute, const QStringList& iOtherAttributes)
 {
-    document=iDocument;
-    table=iTable;
+    m_document = iDocument;
+    m_table = iTable;
 
-    if ( document )
-    {
+    if(m_document) {
         //Keep only existing attribute
         SKGServices::SKGAttributesList attributes;
-        SKGServices::getAttributesDescription ( document, table, attributes );
-        foreach ( const SKGServices::SKGAttributeInfo& att, attributes )
-        {
-            if ( iEditableAttribute.count() ==0 || iEditableAttribute.contains ( att.name ) ) listAtts.push_back ( att );
+        m_document->getAttributesDescription(m_table, attributes);
+        foreach(const SKGServices::SKGAttributeInfo & att, attributes) {
+            if(iEditableAttribute.count() == 0 || iEditableAttribute.contains(att.name)) m_listAtts.push_back(att);
         }
 
 
-        int nbCol=listAtts.count();
-        for ( int i=0; i<nbCol; ++i )
-        {
-            ui.attributeSelect->addItem(listAtts.at(i).icon, (QString) listAtts.at(i).display);
+        int nbCol = m_listAtts.count();
+        for(int i = 0; i < nbCol; ++i) {
+            ui.attributeSelect->addItem(m_listAtts.at(i).icon, (QString) m_listAtts.at(i).display);
         }
 
 
         SKGServices::SKGAttributesList otherAttributes;
-        SKGServices::getAttributesDescription ( document, table, otherAttributes );
-        foreach ( const SKGServices::SKGAttributeInfo& att, otherAttributes )
-        {
-            if ( iOtherAttributes.count() ==0 || iOtherAttributes.contains ( att.name ) ) listOtherAtts.push_back ( att );
+        m_document->getAttributesDescription(m_table, otherAttributes);
+        foreach(const SKGServices::SKGAttributeInfo & att, otherAttributes) {
+            if(iOtherAttributes.count() == 0 || iOtherAttributes.contains(att.name)) m_listOtherAtts.push_back(att);
         }
 
 
-        int nbOthCol=listOtherAtts.count();
-        for ( int i=0; i<nbOthCol; ++i )
-        {
-            ui.otherAttributeSelect->addItem(listOtherAtts.at(i).icon, (QString) listOtherAtts.at(i).display);
+        int nbOthCol = m_listOtherAtts.count();
+        for(int i = 0; i < nbOthCol; ++i) {
+            ui.otherAttributeSelect->addItem(m_listOtherAtts.at(i).icon, (QString) m_listOtherAtts.at(i).display);
         }
 
     }
@@ -99,7 +96,7 @@ void SKGPropertyEditor::setupWidgets()
 {
     int attributeIndex = ui.attributeSelect->currentIndex();
     SKGServices::AttributeType attributeType;
-    attributeType = listAtts.at(attributeIndex).type;
+    attributeType = m_listAtts.at(attributeIndex).type;
 
     int operationIndex = ui.operationSelect->currentIndex();
 
@@ -109,7 +106,7 @@ void SKGPropertyEditor::setupWidgets()
 
     ui.valueSelect->setVisible(attributeType == SKGServices::TEXT && operationIndex == 0);
     QStringList attributeValues;
-    SKGServices::getDistinctValues(document,table,listAtts.at(attributeIndex).name,attributeValues);
+    if(m_document) m_document->getDistinctValues(m_table, m_listAtts.at(attributeIndex).name, attributeValues);
     ui.valueSelect->clear();
     ui.valueSelect->addItem("");
 
@@ -131,17 +128,4 @@ void SKGPropertyEditor::setXMLCondition(QString iXML)
 {
 
 }
-
-QString SKGPropertyEditor::getAttribute()
-{
-    int index = ui.attributeSelect->currentIndex();
-    return listAtts.at(index).name;
-}
-
-QString SKGPropertyEditor::getOperator()
-{
-    if (ui.operationSelect->currentIndex() == 0) {
-        return QString('=');
-    }
-    return "";
-}
+#include "skgpropertyeditor.moc"
