@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -34,29 +34,29 @@ SKGBankObject::~SKGBankObject()
 }
 
 SKGBankObject::SKGBankObject(const SKGBankObject& iObject)
-        :SKGNamedObject(iObject)
+    : SKGNamedObject(iObject)
 {
 }
 
 SKGBankObject::SKGBankObject(const SKGNamedObject& iObject)
 {
-    if (iObject.getRealTable()=="bank") {
+    if(iObject.getRealTable() == "bank") {
         copyFrom(iObject);
     } else {
-        *this=SKGNamedObject(iObject.getDocument(), "v_bank", iObject.getID());
+        *this = SKGNamedObject(iObject.getDocument(), "v_bank", iObject.getID());
     }
 }
 
 SKGBankObject::SKGBankObject(const SKGObjectBase& iObject)
 {
-    if (iObject.getRealTable()=="bank") {
+    if(iObject.getRealTable() == "bank") {
         copyFrom(iObject);
     } else {
-        *this=SKGNamedObject(iObject.getDocument(), "v_bank", iObject.getID());
+        *this = SKGNamedObject(iObject.getDocument(), "v_bank", iObject.getID());
     }
 }
 
-const SKGBankObject& SKGBankObject::operator= (const SKGObjectBase& iObject)
+const SKGBankObject& SKGBankObject::operator= (const SKGObjectBase & iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -65,7 +65,7 @@ const SKGBankObject& SKGBankObject::operator= (const SKGObjectBase& iObject)
 SKGError SKGBankObject::addAccount(SKGAccountObject& oAccount)
 {
     SKGError err;
-    if (getID() == 0) err=SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.",QString("SKGBankObject::addAccount")));
+    if(getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QString("SKGBankObject::addAccount")));
     else {
         oAccount = SKGAccountObject(static_cast<SKGDocumentBank*>(getDocument()));
         err = oAccount.setAttribute("rd_bank_id", SKGServices::intToString(getID()));
@@ -75,9 +75,9 @@ SKGError SKGBankObject::addAccount(SKGAccountObject& oAccount)
 
 SKGError SKGBankObject::getAccounts(SKGListSKGObjectBase& oAccountList) const
 {
-    SKGError err = getObjects(getDocument(), "v_account",
-                              "rd_bank_id=" + SKGServices::intToString(getID()),
-                              oAccountList);
+    SKGError err = getDocument()->getObjects("v_account",
+                   "rd_bank_id=" % SKGServices::intToString(getID()),
+                   oAccountList);
     return err;
 }
 
