@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -37,7 +37,7 @@ public:
      * @param iDocument the document containing the object
      * @param iID the identifier in @p iTable of the object
      */
-    explicit SKGCategoryObject(SKGDocument* iDocument=NULL, int iID=0);
+    explicit SKGCategoryObject(SKGDocument* iDocument = NULL, int iID = 0);
 
     /**
      * Copy constructor
@@ -68,13 +68,15 @@ public:
      * @param iFullPath the full path. Example: cat1 > cat2 > cat3
      * @param oCategory the leaf of the branch
      * @param iSendPopupMessageOnCreation to send a creation message if the category is created
+     * @param iRenameIfAlreadyExist if a leaf with the expected name already exist than the leaf will be renamed and created
      * @return an object managing the error.
      *   @see SKGError
      */
     static SKGError createPathCategory(SKGDocumentBank* iDocument,
                                        const QString& iFullPath,
                                        SKGCategoryObject& oCategory,
-                                       bool iSendPopupMessageOnCreation=false);
+                                       bool iSendPopupMessageOnCreation = false,
+                                       bool iRenameIfAlreadyExist = false);
 
     /**
      * Set the name of this object
@@ -146,6 +148,22 @@ public:
      */
     virtual double getCurrentAmount() const;
 
+    /**
+     * Get all sub operations of this category
+     * @param oSubOperations all sub operations of this category
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError getSubOperations(SKGListSKGObjectBase& oSubOperations) const;
+
+    /**
+     * Merge iCategory in current category
+     * @param iCategory the category. All sub operations will be transferred into this category. The category will be removed
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError merge(const SKGCategoryObject& iCategory);
+
 protected:
     /**
      * Get where clause needed to identify objects.
@@ -157,5 +175,5 @@ protected:
 /**
  * Declare the class
  */
-Q_DECLARE_TYPEINFO ( SKGCategoryObject, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO(SKGCategoryObject, Q_MOVABLE_TYPE);
 #endif
