@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -83,23 +83,6 @@ public Q_SLOTS:
      */
     virtual SKGError addOrModifyAccount(const QString& iName, const QString& iNumber, const QString& iBankName);
 
-    /**
-     * Rename an ccount
-     * @param iName account name
-     * @param inewName new account name
-     * @return an object managing the error.
-     *   @see SKGError
-     */
-    virtual SKGError RenameAccount(const QString& iName, const QString& inewName);
-
-    /**
-     * delete an account
-     * @param iName account name
-     * @return an object managing the error.
-     *   @see SKGError
-     */
-    virtual SKGError deleteAccount(const QString& iName);
-
     /**
      * Create or modify the value of an unit
      * @param iUnitName unit name
@@ -109,33 +92,7 @@ public Q_SLOTS:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError addOrModifyUnitValue(const QString& iUnitName, const QDate& iDate, double iValue, SKGUnitValueObject* oValue=NULL);
-
-    /**
-     * Update unit's attributes
-     * @param iUnitName unit name
-     * @param iInternetCode new Internet code
-     * @return an object managing the error.
-     *   @see SKGError
-     */
-    virtual SKGError ModifyUnit(const QString& iUnitName, const QString& iInternetCode);
-
-    /**
-     * Rename a unit
-     * @param iUnitName old name of the unit
-     * @param inewName new name of the unit
-     * @return an object managing the error.
-     *   @see SKGError
-     */
-    virtual SKGError RenameUnit(const QString& iUnitName, const QString& inewName);
-
-    /**
-     * Delete a unit
-     * @param iUnitName unitname
-     * @return an object managing the error.
-     *   @see SKGError
-     */
-    virtual SKGError deleteUnit(const QString& iUnitName);
+    virtual SKGError addOrModifyUnitValue(const QString& iUnitName, const QDate& iDate, double iValue, SKGUnitValueObject* oValue = NULL);
 
     /**
      * Get formated money
@@ -191,6 +148,13 @@ public Q_SLOTS:
      */
     virtual QString getDisplay(const QString& iString) const;
 
+    /**
+     * Get the real attribute
+     * @param iString the name of the attribute (something like t_BANK)
+     * @return the real attribute (something like bank.rd_bank_id.t_name)
+     */
+    virtual QString getRealAttribute(const QString& iString) const;
+
     /**
      * Get the icon for attribute
      * @param iString the name of the attribute
@@ -217,14 +181,46 @@ public Q_SLOTS:
      */
     virtual QString getDocumentHeader() const;
 
-protected:
     /**
-     * Get impacted tables if one object of @p iTable is modifier.
-     * @param iTable name of a table
-     * @return impacted tables
+     * Get budget report
+     * @param iMonth the month
+     * @return the html report
      */
-    virtual QStringList getImpactedTable(const QString& iTable) const;
+    virtual QString getBudget(const QString& iMonth);
 
+    /**
+     * Get 5 main category report
+     * @param iMonth the month
+     * @param iChart to add chart
+     * @return the html report
+     */
+    virtual QString get5MainCategories(const QString& iMonth, bool iChart = true);
+
+    /**
+     * Get 5 main variation of categories report
+     * @param iMonth the month
+     * @param iPreviousMonth the previous month
+     * @param iOnlyIssues only "Expenses increased" and "Incomes decreased"
+     * @param oCategoryList to get the category for each variation
+     * @return the list of variation string
+     */
+    virtual QStringList get5MainCategoriesVariationList(const QString& iMonth, const QString& iPreviousMonth, bool iOnlyIssues = false, QStringList* oCategoryList = NULL);
+
+    /**
+     * Get 5 main variation of categories report
+     * @param iMonth the month
+     * @param iPreviousMonth the previous month
+     * @param iOnlyIssues only "Expenses increased" and "Incomes decreased"
+     * @return the html report
+     */
+    virtual QString get5MainCategoriesVariation(const QString& iMonth, const QString& iPreviousMonth, bool iOnlyIssues = false);
+
+    /**
+     * Enable/disable balances computation
+     */
+    virtual void setComputeBalances(bool iEnabled);
+
+protected:
     /**
      * Migrate the current SKGDocument to the latest version of the data model.
      * WARNING: This method must be used in a transaction.
@@ -240,13 +236,23 @@ protected:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError computeBalances ();
-
+    virtual SKGError computeBalances();
+    /**
+     * Compute the budgets categories links.
+     * @return an object managing the error.
+     *   @see SKGError
+     */
+    virtual SKGError computeBudgetCategoriesLinks();
 
 private Q_SLOTS:
     virtual void refreshCache(const QString& iTable);
 
 private:
     Q_DISABLE_COPY(SKGDocumentBank);
+
+    QString m_5mainVariations_inputs;
+    QStringList m_5mainVariations_cache;
+    QStringList m_5mainVariationsCat_cache;
+    bool m_computeBalances;
 };
 #endif
