@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -28,10 +28,6 @@
 #include "skgerror.h"
 #include "skgbankmodeler_export.h"
 
-#ifdef SKG_ENABLE_OFX
-#include <libofx/libofx.h>
-#endif
-
 class SKGDocumentBank;
 class SKGAccountObject;
 class SKGUnitObject;
@@ -46,56 +42,38 @@ class SKGBANKMODELER_EXPORT SKGImportExportManager : public QObject
     /**
      * This enumerate defines dump modes
      */
-    Q_ENUMS ( ImportExportMode );
+    Q_ENUMS(ImportExportMode);
 
 public:
-    /**
-     * This enumerate defines dump modes
-     */
-    enum ImportExportMode
-    {
-        AUTO, 		/**< To export or inport in the right mode based on extension file */
-        CSV, 		/**< To export or inport in CSV mode */
-        CSVUNIT, 	/**< To inport in CSV mode values for a unit */
-        GNUCASH,	/**< To inport in GNUCASH file */
-        GSB,		/**< To inport in GRISBI file */
-        XHB,		/**< To inport in HOMEBANK file */
-        SKG,		/**< To export or inport in SKROOGE file */
-        SQLITE,		/**< To export or inport in SQLITE file */
-        KMY,		/**< To export or inport in KMYMONEY file */
-        XML,  		/**< To export in XML mode */
-        QIF,  		/**< To export or inport in QIF mode */
-        OFX 		/**< To export or inport in OFX mode */
-    };
-
     /**
      * Constructor.
      * @param iDocument the document
      * @param iFileName the file name
      * @param iMode the mode
      */
-    explicit SKGImportExportManager ( SKGDocumentBank* iDocument,
-                                      const QString& iFileName="",
-                                      ImportExportMode iMode=SKGImportExportManager::AUTO );
+    explicit SKGImportExportManager(SKGDocumentBank* iDocument,
+                                    const QString& iFileName = "");
 
     /**
      * Destructor
      */
     virtual ~SKGImportExportManager();
 
-    /**
-     * Get the import/export mode.
-     * @return the import/export mode
-     */
-    virtual ImportExportMode getMode();
-
     /**
      * Set the codec used for imports.
      * @param iCodec the codec name.
-     * @return an object managing the error.
-     *   @see SKGError
      */
-    virtual SKGError setCodec ( const QString& iCodec );
+    virtual inline void setCodec(const QString& iCodec) {
+        m_codec = iCodec;
+    }
+
+    /**
+     * Get the codec used for imports.
+     * @return code.
+     */
+    virtual inline QString getCodec() const {
+        return m_codec;
+    }
 
     /**
      * Set the default account for import in case of account is not detected in imported file.
@@ -103,7 +81,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError setDefaultAccount ( SKGAccountObject* iAccount );
+    virtual SKGError setDefaultAccount(SKGAccountObject* iAccount);
 
     /**
      * Set the default unit for import in case of unit is not detected in imported file.
@@ -111,7 +89,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError setDefaultUnit ( SKGUnitObject* iUnit );
+    virtual SKGError setDefaultUnit(SKGUnitObject* iUnit);
 
     /**
      * Enable/disable the automatically validation of imported operations.
@@ -119,14 +97,14 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual void setAutomaticValidation ( bool iValidation );
+    virtual void setAutomaticValidation(bool iValidation);
     /**
      * Enable/disable the automatically rules application on imported operations.
      * @param iApply the mode.
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual void setAutomaticApplyRules ( bool iApply );
+    virtual void setAutomaticApplyRules(bool iApply);
 
     /**
      * Set the CSV mapping rule.
@@ -144,14 +122,37 @@ public:
      * category
      * amount
      * quantity
-     * sign
+     * sign + debit
      * unit
      * This list is a list of operation attributes.
      * @param iCSVMappingRules the mapping. NULL to build automatically the CSV mapping.
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError setCSVMappingRules ( const QMap<QString, QString>& iCSVMappingRules );
+    virtual SKGError setCSVMappingRules(const QMap<QString, QString>& iCSVMappingRules);
+
+    /**
+     * Set the CSV mapping rule.
+     * A mapping rule is a list of regular expression allowing to automatically map each attribute:
+     * the operation object.
+     * List of supported attribute:
+     * date
+     * number
+     * mode
+     * payee
+     * comment
+     * status
+     * bookmarked
+     * account
+     * category
+     * amount
+     * quantity
+     * sign + debit
+     * unit
+     * This list is a list of operation attributes.
+     * @return the mapping rules.
+     */
+    virtual  QMap<QString, QString> getCSVMappingRules();
 
     /**
      * Set the CSV mapping.
@@ -176,7 +177,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError setCSVMapping ( const QStringList* iCSVMapping=NULL );
+    virtual SKGError setCSVMapping(const QStringList* iCSVMapping = NULL);
 
     /**
      * Get the CSV mapping.
@@ -190,7 +191,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError setCSVHeaderIndex ( int iIndex=-1 );
+    virtual SKGError setCSVHeaderIndex(int iIndex = -1);
 
     /**
      * Get the index of the header in the CSV file.
@@ -198,6 +199,18 @@ public:
      */
     virtual int getCSVHeaderIndex();
 
+    /**
+     * Get the CSV separator
+     * @return the separator
+     */
+    virtual QChar getCSVSeparator();
+
+    /**
+     * Get the mime type filter for import
+     * @return the mime type filter
+     */
+    static QString getImportMimeTypeFilter();
+
     /**
      * Import the file in the document
      * @return an object managing the error.
@@ -205,6 +218,12 @@ public:
      */
     virtual SKGError importFile();
 
+    /**
+     * Get the mime type filter for export
+     * @return the mime type filter
+     */
+    static QString getExportMimeTypeFilter();
+
     /**
      * Export the file in the document
      * @return an object managing the error.
@@ -226,7 +245,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError findAndGroupTransfers ( int& oNbOperationsMerged );
+    virtual SKGError findAndGroupTransfers(int& oNbOperationsMerged);
 
     /**
      * Clean operations after an import coming from bank's web sites
@@ -239,21 +258,23 @@ public:
      * Get the document
      * @return the document.
      */
-    virtual SKGDocumentBank* getDocument();
-
+    virtual inline SKGDocumentBank* getDocument() {
+        return m_document;
+    }
     /**
      * Get file name
      * @return the file name.
      */
-    virtual QString getFileName();
-
+    virtual inline QString getFileName() {
+        return m_fileName;
+    }
     /**
      * Return the default account for import
      * @param oAccount the default account for import.
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError getDefaultAccount ( SKGAccountObject& oAccount );
+    virtual SKGError getDefaultAccount(SKGAccountObject& oAccount);
 
     /**
      * Return the preferred unit for a date for import
@@ -266,55 +287,34 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError getDefaultUnit ( SKGUnitObject& oUnit, const QDate* iDate=NULL );
+    virtual SKGError getDefaultUnit(SKGUnitObject& oUnit, const QDate* iDate = NULL);
 
     /**
-     * To know if OFX i supported
-     * @return true or false.
+     * Import units
+     * @return an object managing the error.
+     *   @see SKGError
      */
-    static bool isOFXSupported();
+    virtual SKGError importCSVUnit();
 
 private:
-    Q_DISABLE_COPY ( SKGImportExportManager );
+    Q_DISABLE_COPY(SKGImportExportManager);
 
-    SKGError exportQIF();
-    SKGError exportCSV();
-    SKGError exportOFX();
-    SKGError importQIF();
-    SKGError importCSV();
-#ifdef SKG_ENABLE_OFX
-    SKGError importOFX();
-#endif
-    SKGError importCSVUnit();
-
-#ifdef SKG_ENABLE_OFX
-    static int ofxAccountCallback ( struct OfxAccountData data, void * pv );
-    static int ofxTransactionCallback ( struct OfxTransactionData data, void * pv );
-    static int ofxStatementCallback ( struct OfxStatementData data, void * pv );
-    static QList<OfxStatementData> ofxInitialBalance;
-    static SKGError getAccount(OfxAccountData* iAccountData, SKGDocumentBank* iDoc, SKGAccountObject& oAccount);
-#endif
-
-    static int nbOperationsNotImported;
-    static int nbOperationsImported;
-    static SKGError ofxError;
 
     SKGError finalizedImportedOperations();
 
-    QStringList getCSVMappingFromLine ( const QString& iLine );
+    QStringList getCSVMappingFromLine(const QString& iLine);
 
-    SKGDocumentBank* document;
-    ImportExportMode mode;
-    QString fileName;
-    QStringList csvMapping;
-    QMap<QString, QString>  csvMapper;
-    QChar csvSeparator;
-    int csvHeaderIndex;
-    SKGAccountObject* defaultAccount;
-    SKGUnitObject* defaultUnit;
-    QString codec;
-    bool automaticValidationOfImportedOperation;
-    bool automaticApplyRulesOfImportedOperation;
+    SKGDocumentBank* m_document;
+    QString m_fileName;
+    QStringList m_csvMapping;
+    QMap<QString, QString>  m_csvMapper;
+    QChar m_csvSeparator;
+    int m_csvHeaderIndex;
+    SKGAccountObject* m_defaultAccount;
+    SKGUnitObject* m_defaultUnit;
+    QString m_codec;
+    bool m_automaticValidationOfImportedOperation;
+    bool m_automaticApplyRulesOfImportedOperation;
 };
 
 #endif
