@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -20,27 +20,28 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skginterestobject.h"
+#include "skgdocument.h"
 
 SKGInterestObject::SKGInterestObject(SKGDocument* iDocument, int iID)
-        : SKGObjectBase(iDocument, "v_interest", iID)
+    : SKGObjectBase(iDocument, "v_interest", iID)
 {
 }
 
 SKGInterestObject::SKGInterestObject(const SKGInterestObject& iObject)
-        : SKGObjectBase(iObject)
+    : SKGObjectBase(iObject)
 {
 }
 
 SKGInterestObject::SKGInterestObject(const SKGObjectBase& iObject)
 {
-    if (iObject.getRealTable()=="interest") {
+    if(iObject.getRealTable() == "interest") {
         copyFrom(iObject);
     } else {
-        *this=SKGObjectBase(iObject.getDocument(), "v_interest", iObject.getID());
+        *this = SKGObjectBase(iObject.getDocument(), "v_interest", iObject.getID());
     }
 }
 
-const SKGInterestObject& SKGInterestObject::operator= (const SKGObjectBase& iObject)
+const SKGInterestObject& SKGInterestObject::operator= (const SKGObjectBase & iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -72,45 +73,45 @@ QDate SKGInterestObject::getDate() const
 
 SKGError SKGInterestObject::setIncomeValueDateMode(SKGInterestObject::ValueDateMode iMode)
 {
-    return setAttribute("t_income_value_date_mode", (iMode==FIFTEEN ? "F" : SKGServices::intToString(((int) iMode)-1)));
+    return setAttribute("t_income_value_date_mode", (iMode == FIFTEEN ? "F" : SKGServices::intToString(((int) iMode) - 1)));
 }
 
 SKGInterestObject::ValueDateMode SKGInterestObject::getIncomeValueDateMode() const
 {
-    QString mode=getAttribute("t_income_value_date_mode");
-    return (mode=="F" ? FIFTEEN : (SKGInterestObject::ValueDateMode) (SKGServices::stringToInt(mode)+1));
+    QString mode = getAttribute("t_income_value_date_mode");
+    return (mode == "F" ? FIFTEEN : (SKGInterestObject::ValueDateMode)(SKGServices::stringToInt(mode) + 1));
 }
 
 SKGError SKGInterestObject::setExpenditueValueDateMode(SKGInterestObject::ValueDateMode iMode)
 {
-    return setAttribute("t_expenditure_value_date_mode", (iMode==FIFTEEN ? "F" : SKGServices::intToString(((int) iMode)-1)));
+    return setAttribute("t_expenditure_value_date_mode", (iMode == FIFTEEN ? "F" : SKGServices::intToString(((int) iMode) - 1)));
 }
 
 SKGInterestObject::ValueDateMode SKGInterestObject::getExpenditueValueDateMode() const
 {
-    QString mode=getAttribute("t_expenditure_value_date_mode");
-    return (mode=="F" ? FIFTEEN : (SKGInterestObject::ValueDateMode) (SKGServices::stringToInt(mode)+1));
+    QString mode = getAttribute("t_expenditure_value_date_mode");
+    return (mode == "F" ? FIFTEEN : (SKGInterestObject::ValueDateMode)(SKGServices::stringToInt(mode) + 1));
 }
 
 SKGError SKGInterestObject::setInterestComputationMode(SKGInterestObject::InterestMode iMode)
 {
-    return setAttribute("t_base", (iMode==FIFTEEN24 ? "24" : (iMode==DAYS360 ? "360" : "365")));
+    return setAttribute("t_base", (iMode == FIFTEEN24 ? "24" : (iMode == DAYS360 ? "360" : "365")));
 }
 
 SKGInterestObject::InterestMode SKGInterestObject::getInterestComputationMode() const
 {
-    QString mode=getAttribute("t_base");
-    return (mode=="24" ? FIFTEEN24 :(mode=="360" ? DAYS360 : DAYS365) );
+    QString mode = getAttribute("t_base");
+    return (mode == "24" ? FIFTEEN24 : (mode == "360" ? DAYS360 : DAYS365));
 }
 
 QString SKGInterestObject::getWhereclauseId() const
 {
     //Could we use the id
     QString output = SKGObjectBase::getWhereclauseId();
-    if (output.isEmpty()) {
+    if(output.isEmpty()) {
         //No, so we use the date and parent
-        if (!(getAttribute("d_date").isEmpty()) && !(getAttribute("rd_account_id").isEmpty())) {
-            output = "d_date='"+getAttribute("d_date")+"' AND rd_account_id="+getAttribute("rd_account_id");
+        if(!(getAttribute("d_date").isEmpty()) && !(getAttribute("rd_account_id").isEmpty())) {
+            output = "d_date='" % getAttribute("d_date") % "' AND rd_account_id=" % getAttribute("rd_account_id");
         }
     }
     return output;
@@ -118,12 +119,12 @@ QString SKGInterestObject::getWhereclauseId() const
 
 SKGError SKGInterestObject::setAccount(const SKGAccountObject& iAccount)
 {
-    return setAttribute ( "rd_account_id", SKGServices::intToString ( iAccount.getID() ) );
+    return setAttribute("rd_account_id", SKGServices::intToString(iAccount.getID()));
 }
 
 SKGError SKGInterestObject::getAccount(SKGAccountObject& oAccount) const
 {
-    SKGError err = getObject ( getDocument(), "v_account", "id=" + getAttribute ( "rd_account_id" ), oAccount );
+    SKGError err = getDocument()->getObject("v_account", "id=" % getAttribute("rd_account_id"), oAccount);
     return err;
 }
 
