@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -39,7 +39,7 @@ public:
      * @param iDocument the document containing the object
      * @param iID the identifier in @p iTable of the object
      */
-    explicit SKGPayeeObject(SKGDocument* iDocument=NULL, int iID=0);
+    explicit SKGPayeeObject(SKGDocument* iDocument = NULL, int iID = 0);
 
     /**
      * Copy constructor
@@ -76,10 +76,10 @@ public:
     static SKGError createPayee(SKGDocumentBank* iDocument,
                                 const QString& iName,
                                 SKGPayeeObject& oPayee,
-                                bool iSendPopupMessageOnCreation=false);
+                                bool iSendPopupMessageOnCreation = false);
     /**
      * Get all operations of this payee
-     * @param oOperations all operations of this operation
+     * @param oOperations all operations of this payee
      * @return an object managing the error
      *   @see SKGError
      */
@@ -104,10 +104,18 @@ public:
      * @return the current amount
      */
     virtual double getCurrentAmount() const;
+
+    /**
+     * Merge iPayee in current payee
+     * @param iPayee the payee. All operations will be transferred into this payee. The payee will be removed
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError merge(const SKGPayeeObject& iPayee);
 };
 /**
  * Declare the class
  */
-Q_DECLARE_TYPEINFO ( SKGPayeeObject, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO(SKGPayeeObject, Q_MOVABLE_TYPE);
 
 #endif
