@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -25,6 +25,7 @@
 #include "skgobjectbase.h"
 #include "skgbankmodeler_export.h"
 class SKGOperationObject;
+class SKGDocumentBank;
 
 /**
  * This class manages recurrent operation object
@@ -42,9 +43,9 @@ public:
     /**
      * This enumerate defines the period unit
      */
-    enum PeriodUnit {DAY=0, 	/**< day */
-                     MONTH=1, 	/**< month */
-                     YEAR=2 	/**< year */
+    enum PeriodUnit {DAY = 0,   /**< day */
+                     MONTH = 1, /**< month */
+                     YEAR = 2   /**< year */
                     };
 
     /**
@@ -52,7 +53,7 @@ public:
      * @param iDocument the document containing the object
      * @param iID the identifier in @p iTable of the object
      */
-    explicit SKGRecurrentOperationObject(SKGDocument* iDocument=NULL, int iID=0);
+    explicit SKGRecurrentOperationObject(SKGDocument* iDocument = NULL, int iID = 0);
 
     /**
      * Copy constructor
@@ -252,20 +253,21 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError process(int& oNbInserted, bool iForce=false, const QDate& iDate=QDate::currentDate());
+    virtual SKGError process(int& oNbInserted, bool iForce = false, const QDate& iDate = QDate::currentDate());
 
     /**
      * Warn and/or create operations for all recurrent operations of the document
      * @param iDocument the document containing the object
      * @param oNbInserted number of operations inserted
+     * @param iForce to force the insertion even if autowrite is not enable*
      * @param iDate date limite for insertion
      * @return an object managing the error
      *   @see SKGError
      */
-    static SKGError process(SKGDocument* iDocument, int& oNbInserted, const QDate& iDate=QDate::currentDate());
+    static SKGError process(SKGDocumentBank* iDocument, int& oNbInserted, bool iForce = false, const QDate& iDate = QDate::currentDate());
 };
 /**
  * Declare the class
  */
-Q_DECLARE_TYPEINFO ( SKGRecurrentOperationObject, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO(SKGRecurrentOperationObject, Q_MOVABLE_TYPE);
 #endif
