@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,6 +24,7 @@
 #include "skgcategoryobject.h"
 #include "skgtrackerobject.h"
 #include "skgservices.h"
+#include "skgdocument.h"
 
 #include <klocale.h>
 
@@ -36,20 +37,20 @@ SKGSubOperationObject::~SKGSubOperationObject()
 }
 
 SKGSubOperationObject::SKGSubOperationObject(const SKGSubOperationObject& iObject)
-        : SKGObjectBase(iObject)
+    : SKGObjectBase(iObject)
 {
 }
 
 SKGSubOperationObject::SKGSubOperationObject(const SKGObjectBase& iObject)
 {
-    if (iObject.getRealTable()=="suboperation") {
+    if(iObject.getRealTable() == "suboperation") {
         copyFrom(iObject);
     } else {
-        *this=SKGObjectBase(iObject.getDocument(), "v_suboperation", iObject.getID());
+        *this = SKGObjectBase(iObject.getDocument(), "v_suboperation", iObject.getID());
     }
 }
 
-const SKGSubOperationObject& SKGSubOperationObject::operator= (const SKGObjectBase& iObject)
+const SKGSubOperationObject& SKGSubOperationObject::operator= (const SKGObjectBase & iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -65,9 +66,19 @@ QString SKGSubOperationObject::getComment() const
     return getAttribute("t_comment");
 }
 
+QString SKGSubOperationObject::getFormula() const
+{
+    return getAttribute("t_formula");
+}
+
+SKGError SKGSubOperationObject::setFormula(const QString& iFormula)
+{
+    return setAttribute("t_formula", iFormula);
+}
+
 SKGError SKGSubOperationObject::getParentOperation(SKGOperationObject& oOperation) const
 {
-    SKGError err = getObject(getDocument(), "v_operation", "id=" + getAttribute("rd_operation_id"), oOperation);
+    SKGError err = getDocument()->getObject("v_operation", "id=" % getAttribute("rd_operation_id"), oOperation);
     return err;
 }
 
@@ -79,7 +90,7 @@ SKGError SKGSubOperationObject::setParentOperation(const SKGOperationObject& iOp
 
 SKGError SKGSubOperationObject::getCategory(SKGCategoryObject& oCategory) const
 {
-    SKGError err = getObject(getDocument(), "v_category", "id=" + getAttribute("r_category_id"), oCategory);
+    SKGError err = getDocument()->getObject("v_category", "id=" % getAttribute("r_category_id"), oCategory);
     return err;
 }
 
@@ -104,14 +115,13 @@ SKGError SKGSubOperationObject::setTracker(const SKGTrackerObject& iTracker)
     SKGError err;
     SKGTrackerObject previous;
     getTracker(previous);
-    if (iTracker!=previous)
-    {
-        if (previous.isClosed()) {
-            err=SKGError(ERR_FAIL, i18nc("Error message", "Impossible to remove an operation from a closed tracker"));
-        } else if (iTracker.isClosed()) {
-            err=SKGError(ERR_FAIL, i18nc("Error message", "Impossible to add an operation in a closed tracker"));
+    if(iTracker != previous) {
+        if(previous.isClosed()) {
+            err = SKGError(ERR_FAIL, i18nc("Error message", "Impossible to remove an operation from a closed tracker"));
+        } else if(iTracker.isClosed()) {
+            err = SKGError(ERR_FAIL, i18nc("Error message", "Impossible to add an operation in a closed tracker"));
         } else {
-            err=setAttribute("r_refund_id", SKGServices::intToString(iTracker.getID()));
+            err = setAttribute("r_refund_id", SKGServices::intToString(iTracker.getID()));
         }
     }
     return err;
@@ -119,7 +129,9 @@ SKGError SKGSubOperationObject::setTracker(const SKGTrackerObject& iTracker)
 
 SKGError SKGSubOperationObject::getTracker(SKGTrackerObject& oTracker) const
 {
-    SKGError err = getObject(getDocument(), "v_refund", "id=" + getAttribute("r_refund_id"), oTracker);
+    QString idS = getAttribute("r_refund_id");
+    if(idS.isEmpty()) idS = '0';
+    SKGError err = getDocument()->getObject("v_refund", "id=" % idS, oTracker);
     return err;
 
 }
