@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -46,23 +46,23 @@ public:
     /**
      * This enumerate defines type of units
      */
-    enum UnitType {PRIMARY, 	/**< to define the main currency (only one)*/
-                   SECONDARY, 	/**< to define the seconday currency (only one)*/
-                   CURRENCY, 	/**< for currency: dollar, euro, yen, ... */
-                   SHARE, 		/**< for stock: Google, EDF, ... */
-                   INDEX, 		/**< for index: CAC 40, ... */
-                   OBJECT 		/**< for objects: cars, houses, ... */
+    enum UnitType {PRIMARY,     /**< to define the main currency (only one)*/
+                   SECONDARY,   /**< to define the seconday currency (only one)*/
+                   CURRENCY,    /**< for currency: dollar, euro, yen, ... */
+                   SHARE,       /**< for stock: Google, EDF, ... */
+                   INDEX,       /**< for index: CAC 40, ... */
+                   OBJECT       /**< for objects: cars, houses, ... */
                   };
     /**
      * This enumerate defines the mode of download
      */
-    enum UnitDownloadMode {LAST, 		/**< last value only*/
-                           LAST_MONTHLY, 	/**< one value par month since last download*/
-                           LAST_WEEKLY, 	/**< one value par week since last download*/
-                           LAST_DAILY, 		/**< one value par day since last download*/
-                           ALL_MONTHLY, 	/**< one value par month*/
-                           ALL_WEEKLY, 		/**< one value par week*/
-                           ALL_DAILY 		/**< one value par day*/
+    enum UnitDownloadMode {LAST,        /**< last value only*/
+                           LAST_MONTHLY,    /**< one value par month since last download*/
+                           LAST_WEEKLY,     /**< one value par week since last download*/
+                           LAST_DAILY,      /**< one value par day since last download*/
+                           ALL_MONTHLY,     /**< one value par month*/
+                           ALL_WEEKLY,      /**< one value par week*/
+                           ALL_DAILY        /**< one value par day*/
                           };
 
     /**
@@ -70,7 +70,7 @@ public:
     * @param iDocument the document containing the object
     * @param iID the identifier in @p iTable of the object
     */
-    explicit SKGUnitObject(SKGDocument* iDocument=NULL, int iID=0);
+    explicit SKGUnitObject(SKGDocument* iDocument = NULL, int iID = 0);
 
     /**
      * Destructor
@@ -95,13 +95,20 @@ public:
      */
     SKGUnitObject(const SKGObjectBase& iObject);
 
+    /**
+     * Get unit information
+     * @return the unit information
+     *   @see SKGUnitInfo
+     */
+    virtual SKGServices::SKGUnitInfo getUnitInfo();
+
     /**
      * Get unit information
      * @param iUnitName the currency unit name (nls), or the international code, or the symbol (@see getListofKnownCurrencies)
      * @return the unit information
      *   @see SKGUnitInfo
      */
-    static SKGServices::SKGUnitInfo getUnitInfo( const QString& iUnitName);
+    static SKGServices::SKGUnitInfo getUnitInfo(const QString& iUnitName);
 
     /**
      * Create an existing currency unit
@@ -118,7 +125,7 @@ public:
      * @param iIncludingObsolete including obolete currencies
      * @return the list of known currencies
      */
-    static QStringList getListofKnownCurrencies(bool iIncludingObsolete=false);
+    static QStringList getListofKnownCurrencies(bool iIncludingObsolete = false);
 
     /**
      * Return the International code of currencies.
@@ -253,21 +260,21 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError downloadUnitValue(UnitDownloadMode iMode=LAST, int iNbMaxValues=50, bool iAdditionalInfo=false) const;
+    virtual SKGError downloadUnitValue(UnitDownloadMode iMode = LAST, int iNbMaxValues = 50, bool iAdditionalInfo = false);
 
     /**
      * Get amount of the unit at a date
      * @param iDate date
      * @return amount of the unit
      */
-    virtual double getAmount(const QDate& iDate) const;
+    virtual double getAmount(const QDate& iDate = QDate::currentDate()) const;
 
     /**
      * Get daily change in pourcentage at a date.
      * @param iDate date
      * @return daily change
      */
-    virtual double getDailyChange(const QDate& iDate=QDate::currentDate()) const;
+    virtual double getDailyChange(const QDate& iDate = QDate::currentDate()) const;
 
     /**
      * Set the unit
@@ -302,6 +309,22 @@ public:
      */
     virtual SKGError split(double iRatio) const;
 
+    /**
+     * Get all operations of this unit
+     * @param oOperations all operations of this unit
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError getOperations(SKGListSKGObjectBase& oOperations) const;
+
+    /**
+     * Merge iUnit in current unit
+     * @param iUnit the unit. All operations will be transferred into this unit. The unit will be removed
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError merge(const SKGUnitObject& iUnit);
+
 protected:
     /**
      * Get where clause needed to identify objects.
@@ -313,5 +336,5 @@ protected:
 /**
  * Declare the class
  */
-Q_DECLARE_TYPEINFO ( SKGUnitObject, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO(SKGUnitObject, Q_MOVABLE_TYPE);
 #endif
