@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,7 +23,6 @@
  */
 
 #include <klineedit.h>
-#include <QtDesigner/QDesignerExportWidget>
 #include "skgbasegui_export.h"
 /**
  * This file is a KLineEdit with calculator included
@@ -34,15 +33,19 @@ class SKGBASEGUI_EXPORT SKGCalculatorEdit : public KLineEdit
     /**
      * Value of the calculator editor
      */
-    Q_PROPERTY( double value READ value WRITE setValue USER true)
+    Q_PROPERTY(double value READ value WRITE setValue USER true)
     /**
      * Mode of the calculator editor
      */
-    Q_PROPERTY( SKGCalculatorEdit::Mode mode READ mode WRITE setMode)
+    Q_PROPERTY(SKGCalculatorEdit::Mode mode READ mode WRITE setMode)
     /**
      * Sign of the calculator editor
      */
-    Q_PROPERTY( double sign READ sign )
+    Q_PROPERTY(double sign READ sign)
+    /**
+     * To know if the text is valid
+     */
+    Q_PROPERTY(bool valid READ valid)
     /**
      * Mode of the calculator editor
      */
@@ -78,7 +81,7 @@ public:
      * Set the mode
      * @param iMode the mode
      */
-    virtual void setMode (Mode iMode);
+    virtual void setMode(Mode iMode);
 
     /**
      * Get the value
@@ -91,13 +94,13 @@ public:
      * Set the value
      * @param iValue the value
      */
-    virtual void setValue (double iValue);
+    virtual void setValue(double iValue);
 
     /**
      * Set the text
      * @param iText the text
      */
-    virtual void setText (const QString& iText);
+    virtual void setText(const QString& iText);
 
     /**
      * Get the sign of the value.
@@ -108,28 +111,50 @@ public:
      */
     virtual int sign() const;
 
+    /**
+     * To know if the text is a valid value
+     * @return validation
+     */
+    virtual bool valid() const;
+
+    /**
+     * To formula
+     * @return the formula
+     */
+    virtual QString formula();
+
+    /**
+     * Add a parameter
+     * @param iParameter the parameter name
+     * @param iValue the value
+     */
+    virtual void addParameterValue(const QString& iParameter, double iValue);
+
 protected:
     /**
      * This event handler, for event event, can be reimplemented in a subclass to receive key press events for the widget.
      * @param event the event
      */
-    virtual void keyPressEvent( QKeyEvent * event );
+    virtual void keyPressEvent(QKeyEvent * event);
 
     /**
      * This event handler can be reimplemented in a subclass to receive keyboard focus events (focus lost) for the widget. The events is passed in the event parameter.
      * @param event the event
      */
-    virtual void focusOutEvent ( QFocusEvent * event );
+    virtual void focusOutEvent(QFocusEvent * event);
 
 private:
     Q_DISABLE_COPY(SKGCalculatorEdit);
 
     void keyPressEvent(int key);
-    double lastValue;
-    int lastOperator;
-    Mode currentMode;
+    double m_lastValue;
+    int m_lastOperator;
+    Mode m_currentMode;
+    bool m_valid;
 
-    QColor font_color;
+    QColor m_fontColor;
+    QMap<QString, double> m_parameters;
+    QString m_formula;
 };
 
 #endif // SKGCALCULATOREDIT_H
