@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -27,74 +27,74 @@
 #include <QtPlugin>
 
 SKGComboBoxDesignerPlugin::SKGComboBoxDesignerPlugin(QObject *parent)
-                : QObject(parent)
+    : QObject(parent)
 {
-        initialized = false;
+    m_initialized = false;
 }
 
 void SKGComboBoxDesignerPlugin::initialize(QDesignerFormEditorInterface * /* core */)
 {
-        if (initialized) return;
+    if(m_initialized) return;
 
-        initialized = true;
+    m_initialized = true;
 }
 
 bool SKGComboBoxDesignerPlugin::isInitialized() const
 {
-        return initialized;
+    return m_initialized;
 }
 
 QWidget *SKGComboBoxDesignerPlugin::createWidget(QWidget *parent)
 {
-        return new SKGComboBox(parent);
+    return new SKGComboBox(parent);
 }
 
 QString SKGComboBoxDesignerPlugin::name() const
 {
-        return "SKGComboBox";
+    return "SKGComboBox";
 }
 
 QString SKGComboBoxDesignerPlugin::group() const
 {
-        return "SKG Widgets";
+    return "SKG Widgets";
 }
 
 QIcon SKGComboBoxDesignerPlugin::icon() const
 {
-        return KIcon("skg_open");
+    return KIcon("skg_open");
 }
 
 QString SKGComboBoxDesignerPlugin::toolTip() const
 {
-        return "A combo box with more features";
+    return "A combo box with more features";
 }
 
 QString SKGComboBoxDesignerPlugin::whatsThis() const
 {
-        return "A combo box with more features";
+    return "A combo box with more features";
 }
 
 bool SKGComboBoxDesignerPlugin::isContainer() const
 {
-        return false;
+    return false;
 }
 
 QString SKGComboBoxDesignerPlugin::domXml() const
 {
-        return "<widget class=\"SKGComboBox\" name=\"SKGComboBox\">\n"
-               " <property name=\"geometry\">\n"
-               "  <rect>\n"
-               "   <x>0</x>\n"
-               "   <y>0</y>\n"
-               "   <width>100</width>\n"
-               "   <height>10</height>\n"
-               "  </rect>\n"
-               " </property>\n"
-               "</widget>\n";
+    return "<widget class=\"SKGComboBox\" name=\"SKGComboBox\">\n"
+           " <property name=\"geometry\">\n"
+           "  <rect>\n"
+           "   <x>0</x>\n"
+           "   <y>0</y>\n"
+           "   <width>100</width>\n"
+           "   <height>10</height>\n"
+           "  </rect>\n"
+           " </property>\n"
+           "</widget>\n";
 }
 
 QString SKGComboBoxDesignerPlugin::includeFile() const
 {
-        return "skgcombobox.h";
+    return "skgcombobox.h";
 }
 
