@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,15 +21,15 @@
  */
 #include "skginterfaceplugin.h"
 
-SKGInterfacePlugin::SKGInterfacePlugin ( QObject * parent )
-        :KParts::Plugin ( parent )
+SKGInterfacePlugin::SKGInterfacePlugin(QObject * parent)
+    : KParts::Plugin(parent)
 {}
 SKGInterfacePlugin::~SKGInterfacePlugin()
 {}
 
-void SKGInterfacePlugin::processArguments ( const QStringList& iArgument )
+void SKGInterfacePlugin::processArguments(const QStringList& iArgument)
 {
-    Q_UNUSED ( iArgument );
+    Q_UNUSED(iArgument);
 }
 
 void SKGInterfacePlugin::close() {}
@@ -51,15 +51,15 @@ int SKGInterfacePlugin::getNbDashboardWidgets()
     return 0;
 }
 
-QString SKGInterfacePlugin::getDashboardWidgetTitle ( int iIndex )
+QString SKGInterfacePlugin::getDashboardWidgetTitle(int iIndex)
 {
-    Q_UNUSED ( iIndex );
+    Q_UNUSED(iIndex);
     return "";
 }
 
-SKGWidget* SKGInterfacePlugin::getDashboardWidget ( int iIndex )
+SKGWidget* SKGInterfacePlugin::getDashboardWidget(int iIndex)
 {
-    Q_UNUSED ( iIndex );
+    Q_UNUSED(iIndex);
     return NULL;
 }
 
@@ -83,17 +83,17 @@ int SKGInterfacePlugin::getOrder() const
     return 999;
 }
 
-QString SKGInterfacePlugin::statusTip () const
+QString SKGInterfacePlugin::statusTip() const
 {
     return toolTip();
 }
 
-QString SKGInterfacePlugin::icon () const
+QString SKGInterfacePlugin::icon() const
 {
     return "";
 }
 
-QString SKGInterfacePlugin::toolTip () const
+QString SKGInterfacePlugin::toolTip() const
 {
     return title();
 }
@@ -103,7 +103,7 @@ QStringList SKGInterfacePlugin::tips() const
     return QStringList();
 }
 
-bool SKGInterfacePlugin::isInContext() const
+bool SKGInterfacePlugin::isInPagesChooser() const
 {
     return false;
 }
