@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -43,11 +43,11 @@ public:
      * Describe a modification of an object
      */
     struct SKGAdvice {
-        QString uuid; 				/**< The uuid of the advice */
-        int priority; 				/**< The priority of the advice (0=low, 10=high) */
-        QString shortMessage;			/**< The short message of the advice */
-        QString longMessage;			/**< The long message of the advice */
-        QStringList autoCorrection;		/**< The message in case of this advice could be auto cleaned. One line per possible solutions */
+        QString uuid;               /**< The uuid of the advice */
+        int priority;               /**< The priority of the advice (0=low, 10=high) */
+        QString shortMessage;           /**< The short message of the advice */
+        QString longMessage;            /**< The long message of the advice */
+        QStringList autoCorrection;     /**< The message in case of this advice could be auto cleaned. One line per possible solutions */
     } ;
 
     /**
@@ -67,7 +67,7 @@ public:
      * @param iArgument the arguments
      * @return true if the plugin is compatible with the document
      */
-    virtual bool setupActions(SKGDocument* iDocument, const QStringList& iArgument) =0;
+    virtual bool setupActions(SKGDocument* iDocument, const QStringList& iArgument) = 0;
 
     /**
      * This function is called when the application is launched again with new arguments
@@ -86,8 +86,8 @@ public:
     virtual void refresh();
 
     /**
-     * The context widget of the plugin.
-     * @return The context widget of the plugin
+     * The page widget of the plugin.
+     * @return The page widget of the plugin
      */
     virtual SKGTabPage* getWidget();
 
@@ -141,7 +141,7 @@ public:
      * The title of the plugin.
      * @return The title of the plugin
      */
-    virtual QString title() const =0;
+    virtual QString title() const = 0;
 
     /**
      * The icon of the plugin.
@@ -153,13 +153,13 @@ public:
      * The statusTip of the plugin.
      * @return The toolTip of the plugin
      */
-    virtual QString statusTip () const;
+    virtual QString statusTip() const;
 
     /**
      * The toolTip of the plugin.
      * @return The toolTip of the plugin
      */
-    virtual QString toolTip () const;
+    virtual QString toolTip() const;
 
     /**
      * The tips list of the plugin.
@@ -174,10 +174,10 @@ public:
     virtual int getOrder() const;
 
     /**
-     * Must be implemented to know if a plugin must be display in context chooser.
+     * Must be implemented to know if a plugin must be display in pages chooser.
      * @return true of false (default = false)
      */
-    virtual bool isInContext() const;
+    virtual bool isInPagesChooser() const;
 
     /**
      * Must be implemented to know if this plugin is enabled
@@ -211,6 +211,6 @@ Q_DECLARE_INTERFACE(SKGInterfacePlugin, "skrooge.com.SKGInterfacePlugin/1.0");
 /**
  * Declare the class
  */
-Q_DECLARE_TYPEINFO ( SKGInterfacePlugin::SKGAdvice, Q_PRIMITIVE_TYPE );
+Q_DECLARE_TYPEINFO(SKGInterfacePlugin::SKGAdvice, Q_PRIMITIVE_TYPE);
 
 #endif // SKGINTERFACEPLUGIN_H
