@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -35,7 +35,7 @@ public:
      * Contructor
      * @param parent parent widget
      */
-    SKGSortFilterProxyModel( QObject * parent = 0 );
+    SKGSortFilterProxyModel(QObject * parent = 0);
 
     /**
      * Destructor
@@ -49,7 +49,7 @@ protected:
      * @param source_parent prent
      * @return true of false
      */
-    virtual bool filterAcceptsRow ( int source_row, const QModelIndex & source_parent ) const;
+    virtual bool filterAcceptsRow(int source_row, const QModelIndex & source_parent) const;
 
     /**
      * To sort items
@@ -58,6 +58,9 @@ protected:
      * @return true of false
      */
     virtual bool lessThan(const QModelIndex& left, const QModelIndex& right) const;
+
+private:
+    bool filterAcceptsRowWords(int source_row, const QModelIndex & source_parent, const QStringList& iWords) const;
 };
 
 #endif
