@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -35,66 +35,64 @@
 #include <QStringList>
 
 SKGTabWidget::SKGTabWidget(QWidget *parent)
-        : KTabWidget(parent)
+    : KTabWidget(parent)
 {
-    timerSave = new QTimer( this );
-    timerSave->setSingleShot( true );
-    connect( timerSave, SIGNAL( timeout() ), this, SLOT( onRefreshSaveIcon() ), Qt::QueuedConnection );
-    connect( tabBar(), SIGNAL(moveTab(int, int)), this, SLOT(onMoveTab(int, int)));
-    connect ( static_cast<SKGMainPanel*>(parent), SIGNAL ( currentPageChanged ( ) ), this, SLOT ( onCurrentChanged() ) );
+    m_timerSave.setSingleShot(true);
+    connect(&m_timerSave, SIGNAL(timeout()), this, SLOT(onRefreshSaveIcon()), Qt::QueuedConnection);
+    connect(tabBar(), SIGNAL(moveTab(int, int)), this, SLOT(onMoveTab(int, int)));
+    connect(static_cast<SKGMainPanel*>(parent), SIGNAL(currentPageChanged()), this, SLOT(onCurrentChanged()));
 
     // Use new KDE for moving tabs.
     KTabBar* tabbar = qobject_cast< KTabBar* >(tabBar());
     tabbar->setMovable(true);
 
-    timerSave->start( 1000 );
+    m_timerSave.start(1000);
 }
 
 SKGTabWidget::~SKGTabWidget()
 {
-    timerSave=NULL;
 }
 
 void SKGTabWidget::onCurrentChanged()
 {
-    if (currentWidget() && !mTabIndexSaveButton.keys().contains(currentWidget())) {
+    if(currentWidget() && !m_tabIndexSaveButton.keys().contains(currentWidget())) {
         //Build widgets
         QPushButton* kSave = new QPushButton(this);
         kSave->setIcon(KIcon("document-save"));
-        kSave->setToolTip( i18nc("Verb", "Save this tab" ) );
-        kSave->setFlat( true );
+        kSave->setToolTip(i18nc("Verb", "Save this tab"));
+        kSave->setFlat(true);
         kSave->setMaximumSize(QSize(16, 16));
         kSave->show();
 
         connect(kSave, SIGNAL(clicked()), this, SLOT(onSaveRequested()));
         tabBar()->setTabButton(currentIndex(), QTabBar::LeftSide, kSave);
 
-        mTabIndexSaveButton.insert(currentWidget(), kSave);
+        m_tabIndexSaveButton.insert(currentWidget(), kSave);
     }
 
     //Rebuild indexes
     QMap<QWidget*, QPushButton*> TabIndexSaveButton2;
 
-    int nb=count();
-    for (int i=0; i<nb; ++i) {
-        QWidget* w=widget(i);
-        QPushButton* save=static_cast<QPushButton*>(mTabIndexSaveButton[w]);
-        if (w && save) {
+    int nb = count();
+    for(int i = 0; i < nb; ++i) {
+        QWidget* w = widget(i);
+        QPushButton* save = static_cast<QPushButton*>(m_tabIndexSaveButton[w]);
+        if(w && save) {
             save->setVisible(false);
 
-            QPushButton* s=mTabIndexSaveButton.value(w);
-            if (s!=NULL) TabIndexSaveButton2[w]=s;
+            QPushButton* s = m_tabIndexSaveButton.value(w);
+            if(s != NULL) TabIndexSaveButton2[w] = s;
         }
     }
 
-    mTabIndexSaveButton=TabIndexSaveButton2;
+    m_tabIndexSaveButton = TabIndexSaveButton2;
 
     onRefreshSaveIcon();
 }
 
-void SKGTabWidget::removeTab( int index )
+void SKGTabWidget::removeTab(int index)
 {
-    mTabIndexSaveButton.clear();
+    m_tabIndexSaveButton.clear();
     KTabWidget::removeTab(index);
 }
 
@@ -103,14 +101,14 @@ void SKGTabWidget::onMoveTab(int oldPos, int newPos)
 {
     Q_UNUSED(oldPos);
     Q_UNUSED(newPos);
-    mTabIndexSaveButton.clear();
+    m_tabIndexSaveButton.clear();
     onCurrentChanged();
 }
 
 void SKGTabWidget::onSaveRequested()
 {
-    SKGTabPage *page = dynamic_cast<SKGTabPage*>(currentWidget());
-    if (page) {
+    SKGTabPage *page = qobject_cast<SKGTabPage*>(currentWidget());
+    if(page) {
         page->overwrite(false);
         onRefreshSaveIcon();
     }
@@ -118,13 +116,13 @@ void SKGTabWidget::onSaveRequested()
 
 void SKGTabWidget::onRefreshSaveIcon()
 {
-    SKGTabPage *page = dynamic_cast<SKGTabPage*>(currentWidget());
-    if (page) {
-        QPushButton* save=dynamic_cast<QPushButton*>(mTabIndexSaveButton[page]);
-        if (save) {
-            if (page->isOverwriteNeeded()) {
+    SKGTabPage *page = qobject_cast<SKGTabPage*>(currentWidget());
+    if(page) {
+        QPushButton* save = qobject_cast<QPushButton*>(m_tabIndexSaveButton[page]);
+        if(save) {
+            if(page->isOverwriteNeeded()) {
                 save->show();
-                if (page->getBookmarkID().isEmpty()) {
+                if(page->getBookmarkID().isEmpty()) {
                     save->setIcon(KIcon("document-save"));
                 } else {
                     QStringList overlay;
@@ -134,7 +132,7 @@ void SKGTabWidget::onRefreshSaveIcon()
             } else save->hide();
         }
 
-        if (timerSave) timerSave->start( 1000 );
+        m_timerSave.start(1000);
     }
 }
 #include "skgtabwidget.moc"
