@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -25,11 +25,10 @@
 
 #include <ktabwidget.h>
 
-#include <QtDesigner/QDesignerExportWidget>
 #include <QMap>
+#include <QTimer>
 
 class QPushButton;
-class QTimer;
 
 /**
  * A KTabWidget with more features.
@@ -55,7 +54,7 @@ public Q_SLOTS:
      * Remove a tab
      * @param index the tab index
      */
-    virtual void removeTab( int index );
+    virtual void removeTab(int index);
 
 private Q_SLOTS:
     void onCurrentChanged();
@@ -64,9 +63,9 @@ private Q_SLOTS:
     void onMoveTab(int oldPos, int newPos);
 
 private:
-    QTimer* timerSave;
+    QTimer m_timerSave;
 
-    QMap<QWidget*, QPushButton*> mTabIndexSaveButton;
+    QMap<QWidget*, QPushButton*> m_tabIndexSaveButton;
 };
 
 #endif // SKGTABWIDGET_H
