@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -28,8 +28,6 @@
 #include <kglobal.h>
 #include <QStringList>
 #include <QTreeView>
-#include <QtDesigner/QDesignerExportWidget>
-#include <QBasicTimer>
 
 #include <kmenu.h>
 #include "skgmainpanel.h"
@@ -46,22 +44,22 @@ class SKGBASEGUI_EXPORT SKGTreeView : public QTreeView
     /**
      * State of the view
      */
-    Q_PROPERTY ( QString state READ getState WRITE setState USER true )
+    Q_PROPERTY(QString state READ getState WRITE setState USER true)
     /**
      * Text resizable by CTRL+wheel
      */
-    Q_PROPERTY ( bool textResizable READ isTextResizable WRITE setTextResizable )
+    Q_PROPERTY(bool m_textResizable READ isTextResizable WRITE setTextResizable)
     /**
      * Auto resize mode of the view
      */
-    Q_PROPERTY ( bool autoResized READ isAutoResized )
+    Q_PROPERTY(bool autoResized READ isAutoResized)
 
 public:
     /**
      * Default Constructor
      * @param parent the parent
      */
-    SKGTreeView ( QWidget *parent = 0 );
+    SKGTreeView(QWidget *parent = 0);
 
     /**
      * Default Destructor
@@ -80,7 +78,7 @@ public:
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    virtual void setState ( const QString& iState );
+    virtual void setState(const QString& iState);
 
     /**
      * To know if the autoresized mode is enable
@@ -92,7 +90,7 @@ public:
     * @param iDocument document pointer
     * @param iParameterName parameter name in this document
     */
-    virtual void setDefaultSaveParameters ( SKGDocument* iDocument, const QString& iParameterName );
+    virtual void setDefaultSaveParameters(SKGDocument* iDocument, const QString& iParameterName);
 
     /**
      * Get the table content
@@ -106,6 +104,12 @@ public:
      */
     virtual SKGObjectBase::SKGListSKGObjectBase getSelectedObjects();
 
+    /**
+     * Get the first selected object
+     * @return first selected object
+     */
+    virtual SKGObjectBase getFirstSelectedObject();
+
     /**
      * Get the number of seleted object
      * @return number of selected objects
@@ -116,14 +120,14 @@ public:
      * Sets the current selection model to the given selectionModel.
      * @param selectionModel the selection model
      */
-    virtual void setSelectionModel ( QItemSelectionModel * selectionModel );
+    virtual void setSelectionModel(QItemSelectionModel * selectionModel);
 
     /**
      * Insert a registered action
      * @see SKGMainPanel::registedGlobalAction
      * @param iRegisteredAction the registered action. "" means separator
      */
-    virtual void insertGlobalAction(const QString& iRegisteredAction="");
+    virtual void insertGlobalAction(const QString& iRegisteredAction = "");
 
 Q_SIGNALS:
     /**
@@ -149,32 +153,32 @@ protected:
      * If a valid item is pressed on it is made into the current item. This function emits the pressed() signal.
      * @param event the event
      */
-    virtual void mousePressEvent ( QMouseEvent * event );
+    virtual void mousePressEvent(QMouseEvent * event);
 
 public Q_SLOTS:
     /**
      * This property holds whether to autorize text size modification by CTRL+wheel.
      * @param resizable true of false
      */
-    virtual void setTextResizable ( bool resizable );
+    virtual void setTextResizable(bool resizable);
 
     /**
      * Get the property to know if text is resizable
      * @return the property
      */
-    virtual bool isTextResizable () const;
+    virtual bool isTextResizable() const;
 
     /**
      * Set the zoom position.
      * @param iZoomPosition zoom position (-10<=zoom position<=10)
      */
-    virtual void setZoomPosition ( int iZoomPosition );
+    virtual void setZoomPosition(int iZoomPosition);
 
     /**
      * Get zoom position
      * @return zoom position (-10<=zoom position<=10)
      */
-    virtual int zoomPosition () const;
+    virtual int zoomPosition() const;
 
     /**
      * Save the selection
@@ -195,20 +199,20 @@ public Q_SLOTS:
      * Select an object and focus on it
      * @param iUniqueID unique ID of the object
      */
-    virtual void selectObject ( const QString& iUniqueID );
+    virtual void selectObject(const QString& iUniqueID);
 
     /**
      * Select objects and focus on the first one
      * @param iUniqueIDs unique IDs of objects
      * @param iFocusOnFirstOne set the focus on the first one
      */
-    virtual void selectObjects ( const QStringList& iUniqueIDs, bool iFocusOnFirstOne=false );
+    virtual void selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirstOne = false);
 
     /**
      * This property holds whether to draw the background using alternating colors.
      * @param enable true of false
      */
-    virtual void setAlternatingRowColors ( bool enable );
+    virtual void setAlternatingRowColors(bool enable);
 
     /**
      * Reset columns order
@@ -225,6 +229,10 @@ public Q_SLOTS:
      */
     virtual void resizeColumnsToContentsDelayed();
 
+    /**
+     * When the selection changed
+     */
+    virtual void onSelectionChanged();
 
 protected:
     /**
@@ -233,52 +241,40 @@ protected:
       * @param event event
       * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
       */
-    virtual bool eventFilter ( QObject *object, QEvent *event );
+    virtual bool eventFilter(QObject *object, QEvent *event);
 
 private Q_SLOTS:
-    void onExportPDF();
-    void onExportCSV();
-    void onExportTXT();
-
+    void onExport();
     void moveSection();
-    void setupHeaderMenu ( bool iRefreshColumnSize=true );
-    void showHeaderMenu ( const QPoint& pos );
+    void setupHeaderMenu(bool iRefreshColumnSize = true);
+    void showHeaderMenu(const QPoint& pos);
     void showHideColumn();
     void switchAutoResize();
     void changeSchema();
     void saveDefaultClicked();
 
-    void onSelectionChanged();
-    void onSortChanged ();
+    void onSortChanged();
 
-    void onExpand ( const QModelIndex & index );
-    void onCollapse ( const QModelIndex & index );
+    void onExpand(const QModelIndex & index);
+    void onCollapse(const QModelIndex & index);
 
 private:
-    Q_DISABLE_COPY ( SKGTreeView );
+    Q_DISABLE_COPY(SKGTreeView);
 
-    KMenu* header_menu;
-    bool autoResize;
-    QAction* actAutoResize;
-    SKGDocument* document;
-    QString parameterName;
-    QStringList selection;
-    QStringList expandedNodes;
+    KMenu* m_headerMenu;
+    bool m_autoResize;
+    QAction* m_actAutoResize;
+    SKGDocument* m_document;
+    QString m_parameterName;
+    QStringList m_selection;
+    QStringList m_expandedNodes;
 
-    typedef enum { Steady, Pressed, ManualScroll, AutoScroll, Stop } State;
-    State state;
-    QPoint pressPos;
-    QPoint offset;
-    QPoint dragPos;
-    QPoint speed;
-    QList<QEvent*> ignored;
-    QBasicTimer ticker;
-    QTimer* timerDelayedResize;
-    QTimer* timerSelectionChanged;
-    QTimer* timerScrollSelection;
-    bool textResizable;
-    int fontOriginalPointSize;
-    int iconOriginalSize;
+    QTimer m_timerDelayedResize;
+    QTimer m_timerSelectionChanged;
+    QTimer m_timerScrollSelection;
+    bool m_textResizable;
+    int m_fontOriginalPointSize;
+    int m_iconOriginalSize;
 };
 
 #endif // SKGTREEVIEW_H
