@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -31,30 +31,38 @@
 #include "skgtablewithgraphdesignerplugin.h"
 #include "skgtabwidgetdesignerplugin.h"
 #include "skgtablewidgetdesignerplugin.h"
+#include "skgwebviewdesignerplugin.h"
 #include "skgzoomselectordesignerplugin.h"
+#include "skgshowdesignerplugin.h"
+#include "skgfilteredtableviewdesignerplugin.h"
+#include "skgwidgetselectordesignerplugin.h"
 
 #include <QtPlugin>
 
 SKGWidgetCollectionDesignerPlugin::SKGWidgetCollectionDesignerPlugin(QObject *parent)
-        : QObject(parent)
+    : QObject(parent)
 {
-    widgets.append(new SKGCalculatorEditDesignerPlugin(this));
-    widgets.append(new SKGComboBoxDesignerPlugin(this));
-    widgets.append(new SKGColorButtonDesignerPlugin(this));
-    widgets.append(new SKGLineEditDesignerPlugin(this));
-    widgets.append(new SKGDateEditDesignerPlugin(this));
-    widgets.append(new SKGGraphicsViewDesignerPlugin(this));
-    widgets.append(new SKGTableViewDesignerPlugin(this));
-    widgets.append(new SKGTreeViewDesignerPlugin(this));
-    widgets.append(new SKGTableWithGraphDesignerPlugin(this));
-    widgets.append(new SKGTabWidgetDesignerPlugin(this));
-    widgets.append(new SKGTableWidgetDesignerPlugin(this));
-    widgets.append(new SKGZoomSelectorDesignerPlugin(this));
+    m_widgets.append(new SKGCalculatorEditDesignerPlugin(this));
+    m_widgets.append(new SKGComboBoxDesignerPlugin(this));
+    m_widgets.append(new SKGColorButtonDesignerPlugin(this));
+    m_widgets.append(new SKGLineEditDesignerPlugin(this));
+    m_widgets.append(new SKGDateEditDesignerPlugin(this));
+    m_widgets.append(new SKGFilteredTableViewDesignerPlugin(this));
+    m_widgets.append(new SKGGraphicsViewDesignerPlugin(this));
+    m_widgets.append(new SKGShowDesignerPlugin(this));
+    m_widgets.append(new SKGTableViewDesignerPlugin(this));
+    m_widgets.append(new SKGTreeViewDesignerPlugin(this));
+    m_widgets.append(new SKGTableWithGraphDesignerPlugin(this));
+    m_widgets.append(new SKGTabWidgetDesignerPlugin(this));
+    m_widgets.append(new SKGTableWidgetDesignerPlugin(this));
+    m_widgets.append(new SKGWebViewDesignerPlugin(this));
+    m_widgets.append(new SKGWidgetSelectorDesignerPlugin(this));
+    m_widgets.append(new SKGZoomSelectorDesignerPlugin(this));
 }
 
 QList<QDesignerCustomWidgetInterface*> SKGWidgetCollectionDesignerPlugin::customWidgets() const
 {
-    return widgets;
+    return m_widgets;
 }
 
 Q_EXPORT_PLUGIN2(skgbaseui, SKGWidgetCollectionDesignerPlugin)
