@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,24 +24,30 @@
 
 #include <qtextstream.h>
 
-SKGZoomSelector::SKGZoomSelector ( QWidget *parent )
-        : QWidget ( parent )
+SKGZoomSelector::SKGZoomSelector(QWidget *parent)
+    : QWidget(parent), m_resetValue(0)
 {
-    ui.setupUi ( this );
+    ui.setupUi(this);
 
     //Set icons
-    ui.kZoomIn->setIcon ( KIcon ( "zoom-in" ) );
-    ui.kZoomOut->setIcon ( KIcon ( "zoom-out" ) );
-    ui.kZoomOriginal->setIcon ( KIcon ( "zoom-original" ) );
+    ui.kZoomIn->setIcon(KIcon("zoom-in"));
+    ui.kZoomOut->setIcon(KIcon("zoom-out"));
+    ui.kZoomOriginal->setIcon(KIcon("zoom-original"));
+
+    //Init timer
+    m_timer.setSingleShot(true);
+    connect(&m_timer, SIGNAL(timeout()), this, SLOT(onZoomChanged()));
 }
 
 SKGZoomSelector::~SKGZoomSelector()
 {
 }
 
-void SKGZoomSelector::setValue(int iValue)
+void SKGZoomSelector::setValue(int iValue, bool iEmitEvent)
 {
+    bool previous = ui.kZoomSlider->blockSignals(!iEmitEvent);
     ui.kZoomSlider->setValue(iValue);
+    ui.kZoomSlider->blockSignals(previous);
 }
 
 int SKGZoomSelector::value() const
@@ -49,27 +55,42 @@ int SKGZoomSelector::value() const
     return ui.kZoomSlider->value();
 }
 
-void SKGZoomSelector::onZoomIn()
+int SKGZoomSelector::resetValue() const
 {
-    ui.kZoomSlider->setValue ( ui.kZoomSlider->value() + 1 );
+    return m_resetValue;
 }
 
-void SKGZoomSelector::onZoomOut()
+void SKGZoomSelector::setResetValue(int iValue)
 {
-    ui.kZoomSlider->setValue ( ui.kZoomSlider->value() - 1 );
+    m_resetValue = iValue;
 }
 
-void SKGZoomSelector::onZoomInit()
+void SKGZoomSelector::zoomIn()
 {
-    ui.kZoomSlider->setValue ( 0 );
+    ui.kZoomSlider->setValue(ui.kZoomSlider->value() + 1);
+}
+
+void SKGZoomSelector::zoomOut()
+{
+    ui.kZoomSlider->setValue(ui.kZoomSlider->value() - 1);
+}
+
+void SKGZoomSelector::initializeZoom()
+{
+    ui.kZoomSlider->setValue(m_resetValue);
+}
+
+void SKGZoomSelector::onZoomChangedDelayed()
+{
+    m_timer.start(300);
 }
 
 void SKGZoomSelector::onZoomChanged()
 {
-    int val=ui.kZoomSlider->value();
-    if (ui.kZoomIn) ui.kZoomIn->setEnabled(val<10);
-    if (ui.kZoomOut) ui.kZoomOut->setEnabled(val>-10);
-    if (ui.kZoomOriginal) ui.kZoomOriginal->setChecked(val==0);
+    int val = ui.kZoomSlider->value();
+    if(ui.kZoomIn) ui.kZoomIn->setEnabled(val < 10);
+    if(ui.kZoomOut) ui.kZoomOut->setEnabled(val > -10);
+    if(ui.kZoomOriginal) ui.kZoomOriginal->setChecked(val == 0);
 
     Q_EMIT changed(val);
 }
