@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,6 +22,7 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgservices.h"
+#include "skgobjectbase.h"
 #include "skgbasemodeler_export.h"
 
 #include <QStringList>
@@ -70,10 +71,10 @@ public:
      * Describe a modification of an object
      */
     struct SKGObjectModification {
-        QString uuid; 				/**< The uuid of the object */
-        int id; 				/**< The id of the object */
-        QString table; 				/**< The table of the object */
-        ModificationType type; 			/**< The type of modification */
+        QString uuid;               /**< The uuid of the object */
+        int id;                 /**< The id of the object */
+        QString table;              /**< The table of the object */
+        ModificationType type;          /**< The type of modification */
     } ;
 
     /**
@@ -100,9 +101,9 @@ public:
      * This enumerate defines the direction of the UNDO / REDO mechanism
      */
     enum UndoRedoMode {
-        UNDOLASTSAVE, 	/**< To do/get an undo=cancel of the last successfully extecuted transactions until last save */
-        UNDO, 		/**< To do/get an undo=cancel of the last successfully extecuted transaction */
-        REDO  		/**< To do/get a redo=replay the last cancelled transaction */
+        UNDOLASTSAVE,   /**< To do/get an undo=cancel of the last successfully extecuted transactions until last save */
+        UNDO,       /**< To do/get an undo=cancel of the last successfully extecuted transaction */
+        REDO        /**< To do/get a redo=replay the last cancelled transaction */
     };
 
     /**
@@ -124,7 +125,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setProgressCallback(int (*iProgressFunction)(int, void*), void* iData=NULL);
+    virtual SKGError setProgressCallback(int (*iProgressFunction)(int, void*), void* iData = NULL);
 
 public Q_SLOTS:
     /**
@@ -154,7 +155,7 @@ public Q_SLOTS:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError beginTransaction(const QString & iName, int iNbStep=0, const QDateTime& iDate=QDateTime::currentDateTime());
+    virtual SKGError beginTransaction(const QString & iName, int iNbStep = 0, const QDateTime& iDate = QDateTime::currentDateTime());
 
     /**
      * Close the current transaction.
@@ -182,7 +183,7 @@ public Q_SLOTS:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError sendMessage(const QString& iMessage, bool iPopup=true);
+    virtual SKGError sendMessage(const QString& iMessage, bool iPopup = true);
 
     /**
      * Get message attached to a current transaction.
@@ -192,7 +193,7 @@ public Q_SLOTS:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError getMessages(int iIdTransaction, QStringList& oMessages, bool iAll=true);
+    virtual SKGError getMessages(int iIdTransaction, QStringList& oMessages, bool iAll = true);
 
     /**
      * Get list of direct modifications done in a transaction
@@ -238,7 +239,7 @@ public Q_SLOTS:
      * 0 if no transaction found
      */
     virtual int getTransactionToProcess(const UndoRedoMode& iMode = SKGDocument::UNDO, QString* oName = NULL,
-                                        bool* oSaveStep=NULL, QDateTime* oDate=NULL) const;
+                                        bool* oSaveStep = NULL, QDateTime* oDate = NULL) const;
 
     /**
      * Return the identifier of the current transaction
@@ -297,7 +298,7 @@ public Q_SLOTS:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError load(const QString & iName, const QString & iPassword="", bool iRestoreTmpFile=false);
+    virtual SKGError load(const QString & iName, const QString & iPassword = "", bool iRestoreTmpFile = false);
 
     /**
      * To know if the current document has been modified or not.
@@ -331,7 +332,7 @@ public Q_SLOTS:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError saveAs(const QString & iName, bool iOverwrite=false);
+    virtual SKGError saveAs(const QString & iName, bool iOverwrite = false);
 
     /**
      * close the current SKGDocument.
@@ -346,7 +347,7 @@ public Q_SLOTS:
      * @param iWhereClause the additional where clause.
      * @return the list of parameters.
      */
-    virtual QStringList getParameters(const QString& iParentUUID, const QString& iWhereClause="");
+    virtual QStringList getParameters(const QString& iParentUUID, const QString& iWhereClause = "");
 
     /**
      * Get a parameter value
@@ -354,7 +355,7 @@ public Q_SLOTS:
      * @param iParentUUID the unique identifier of the object owning this parameter.
      * @return the value.
      */
-    virtual QString getParameter(const QString& iName, const QString& iParentUUID="document");
+    virtual QString getParameter(const QString& iName, const QString& iParentUUID = "document");
 
     /**
      * Get a parameter blob
@@ -362,7 +363,7 @@ public Q_SLOTS:
      * @param iParentUUID the unique identifier of the object owning this parameter.
      * @return the blob.
      */
-    virtual QVariant getParameterBlob(const QString& iName, const QString& iParentUUID="document");
+    virtual QVariant getParameterBlob(const QString& iName, const QString& iParentUUID = "document");
 
     /**
      * Set a parameter.
@@ -377,7 +378,7 @@ public Q_SLOTS:
      *   @see SKGError
      */
     virtual SKGError setParameter(const QString& iName, const QString& iValue, const QString& iFileName,
-                                  const QString& iParentUUID="document", SKGPropertyObject* oObjectCreated=NULL);
+                                  const QString& iParentUUID = "document", SKGPropertyObject* oObjectCreated = NULL);
 
     /**
      * Set a parameter.
@@ -391,8 +392,8 @@ public Q_SLOTS:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError setParameter(const QString& iName, const QString& iValue, const QVariant& iBlob=QVariant(),
-                                  const QString& iParentUUID="document", SKGPropertyObject* oObjectCreated=NULL);
+    virtual SKGError setParameter(const QString& iName, const QString& iValue, const QVariant& iBlob = QVariant(),
+                                  const QString& iParentUUID = "document", SKGPropertyObject* oObjectCreated = NULL);
 
     /**
      * Get the database pointer.
@@ -434,7 +435,7 @@ public Q_SLOTS:
                                          const QString& iOpAtt,
                                          const QString& iWhereClause,
                                          SKGStringListList& oTable,
-                                         const QString& iMissingValue="0");
+                                         const QString& iMissingValue = "0");
 
     /**
      * Refresh all views and indexes in the database
@@ -464,6 +465,13 @@ public Q_SLOTS:
      */
     virtual QIcon getIcon(const QString& iString) const;
 
+    /**
+     * Get the real attribute
+     * @param iString the name of the attribute (something like t_BANK)
+     * @return the real attribute (something like bank.rd_bank_id.t_name)
+     */
+    virtual QString getRealAttribute(const QString& iString) const;
+
     /**
      * Get the attribute type
      * @param iAttributeName the name of an attribute
@@ -492,7 +500,7 @@ public Q_SLOTS:
      * @param iPrefix the prefix for the backup file
      * @param iSuffix the suffix for backup file
      */
-    virtual void setBackupParameters(const QString& iPrefix="", const QString& iSuffix="");
+    virtual void setBackupParameters(const QString& iPrefix = "", const QString& iSuffix = "");
 
     /**
      * Get the temporary file for a file
@@ -519,6 +527,164 @@ public Q_SLOTS:
      */
     virtual QString getDocumentHeader() const;
 
+    /**
+     * Return a number of objects (@p oNbObjects) corresponding to a where clause (@p iWhereClause )
+     * @param iTable the table where to search
+     * @param iWhereClause the where clause
+     * @param oNbObjects the result
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError getNbObjects(const QString& iTable, const QString& iWhereClause, int& oNbObjects) const;
+
+    /**
+     * To know if at least one object exist (@p oListObject) corresponding to a where clause (@p oExist )
+     * @param iTable the table where to search
+     * @param iWhereClause the where clause
+     * @param oExist the result
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError existObjects(const QString& iTable, const QString& iWhereClause, bool& oExist) const;
+
+    /**
+     * Return a list of objects (@p oListObject) corresponding to a where clause (@p iWhereClause )
+     * @param iTable the table where to search
+     * @param iWhereClause the where clause
+     * @param oListObject the result
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError getObjects(const QString& iTable, const QString& iWhereClause, SKGObjectBase::SKGListSKGObjectBase& oListObject) const;
+
+    /**
+     * Return the object (@p oObject) corresponding to a where clause (@p iWhereClause ).
+     * If more than one objects are returned by the query, then an error is generated
+     * If 0 object is returned by the query, then an error is generated
+     * @param iTable the table where to search
+     * @param iWhereClause the where clause
+     * @param oObject the result
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError getObject(const QString& iTable, const QString& iWhereClause, SKGObjectBase& oObject) const;
+
+    /**
+     * Return the object (@p oObject) corresponding to an id (@p iId ).
+     * If more than one objects are returned by the query, then an error is generated
+     * If 0 object is returned by the query, then an error is generated
+     * @param iTable the table where to search
+     * @param iId id of the object in @p iTable
+     * @param oObject the result
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError getObject(const QString& iTable, int iId, SKGObjectBase& oObject) const;
+
+    /**
+     * Retrieve list of tables
+     * @param oResult the output result
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError getTablesList(QStringList& oResult) const;
+
+    /**
+     * Retrieve all distinct values of an attribute of a table
+     * @param iTable the table where to look for
+     * @param iAttribute the attribute wanted (only one)
+     * @param iWhereClause a whereclause
+     * @param oResult the output result
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError getDistinctValues(const QString& iTable, const QString& iAttribute, const QString& iWhereClause, QStringList& oResult) const;
+
+    /**
+     * Retrieve all distinct values of an attribute of a table
+     * @param iTable the table where to look for
+     * @param iAttribute the attribute wanted (only one)
+     * @param oResult the output result
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError getDistinctValues(const QString& iTable, const QString& iAttribute, QStringList& oResult) const;
+
+    /**
+     * Execute a sqlite orders
+     * @param iSqlOrders the sql orders
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError executeSqliteOrders(const QStringList& iSqlOrders) const;
+
+    /**
+     * Execute a sqlite order
+     * @param iSqlOrder the sql order
+     * @param iLastId to retrieve the id of the last created object
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError executeSqliteOrder(const QString& iSqlOrder, int* iLastId = NULL) const;
+
+    /**
+    * Execute a select sqlite order and return the result in @p oResult
+    * @param iSqlOrder the sql order
+    * @param oResult the result of the select. It's a vector of vector of QString
+    * @return An object managing the error
+    *   @see SKGError
+    */
+    virtual SKGError executeSelectSqliteOrder(const QString& iSqlOrder, SKGStringListList& oResult) const;
+
+    /**
+    * dump a select sqlite order
+    * @param iSqlOrder the sql order
+    * @param oStream the output stream, NULL for std output (cout)
+    * @param iMode dump mode
+    * @return An object managing the error
+    *   @see SKGError
+    */
+    virtual SKGError dumpSelectSqliteOrder(const QString& iSqlOrder, QTextStream* oStream = NULL, SKGServices::DumpMode iMode = SKGServices::DUMP_TEXT) const;
+
+    /**
+     * dump a select sqlite order
+     * @param iSqlOrder the sql order
+     * @param oResult the output
+     * @param iMode dump mode
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError dumpSelectSqliteOrder(const QString& iSqlOrder, QString& oResult, SKGServices::DumpMode iMode = SKGServices::DUMP_TEXT) const;
+
+    /**
+     * dump a select sqlite order
+     * @param iSqlOrder the sql order
+     * @param oResult the output
+     * @param iMode dump mode
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError dumpSelectSqliteOrder(const QString& iSqlOrder, QStringList& oResult, SKGServices::DumpMode iMode = SKGServices::DUMP_TEXT) const;
+
+    /**
+     * Retrieve description of each attribute of a table
+     * @param iTable the table where to look for
+     * @param oResult the output result
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError getAttributesDescription(const QString& iTable, SKGServices::SKGAttributesList& oResult) const;
+
+    /**
+     * Retrieve list of attributes
+     * @param iTable the table where to look for
+     * @param oResult the output result
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError getAttributesList(const QString& iTable, QStringList& oResult) const;
+
+
 Q_SIGNALS:
     /**
      * This signal is launched by endTransaction on all tables modified when a huge modification occures on the model
@@ -583,39 +749,40 @@ protected:
      * @param iTable name of a table
      * @return impacted tables
      */
-    virtual QStringList getImpactedTable(const QString& iTable) const;
+    virtual QStringList getImpactedTables(const QString& iTable);
 
 private:
     Q_DISABLE_COPY(SKGDocument);
 
     QString getBackupFile(const QString iFileName);
 
-    static SKGError lastCallbackError;
+    static SKGError m_lastCallbackError;
 
-    static int databaseUniqueIdentifier;
+    static int m_databaseUniqueIdentifier;
 
-    int lastSavedTransaction;
-    void* progressFunction;
-    void* progressData;
-    QString currentFileName;
-    QString databaseIdentifier;
-    QSqlDatabase* currentDatabase;
-    SKGIntList nbStepForTransaction;
-    SKGIntList posStepForTransaction;
-    int inundoRedoTransaction;
-    int currentTransaction;
-    QString temporaryFile;
-    QString uniqueIdentifier;
-    QStringList unTransactionnalMessages;
+    int m_lastSavedTransaction;
+    void* m_progressFunction;
+    void* m_progressData;
+    QString m_currentFileName;
+    QString m_databaseIdentifier;
+    QSqlDatabase* m_currentDatabase;
+    SKGIntList m_nbStepForTransaction;
+    SKGIntList m_posStepForTransaction;
+    int m_inundoRedoTransaction;
+    int m_currentTransaction;
+    QString m_temporaryFile;
+    QString m_uniqueIdentifier;
+    QStringList m_unTransactionnalMessages;
+    QMap<QString, QStringList> m_ImpactedViews;
 
-    QHash<QString, QString> cache;
-    bool inProgress;
-    QString backupPrefix;
-    QString backupSuffix;
-    bool directAccessDb;
+    QHash<QString, QString> m_cache;
+    bool m_inProgress;
+    QString m_backupPrefix;
+    QString m_backupSuffix;
+    bool m_directAccessDb;
 };
 /**
  * Declare the class
  */
-Q_DECLARE_TYPEINFO ( SKGDocument::SKGModelTemplate, Q_PRIMITIVE_TYPE );
+Q_DECLARE_TYPEINFO(SKGDocument::SKGModelTemplate, Q_PRIMITIVE_TYPE);
 #endif
