@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,106 +21,137 @@
 */
 #include "skgerror.h"
 
+QDBusArgument& operator<<(QDBusArgument &iArgument, const SKGError& iError)
+{
+    iArgument.beginStructure();
+    iArgument << iError.getReturnCode() << iError.getMessage();
+    iArgument.endStructure();
+    return iArgument;
+}
+const QDBusArgument& operator>>(const QDBusArgument &iArgument, SKGError& iError)
+{
+    iArgument.beginStructure();
+    int rc = 0;
+    iArgument >> rc;
+    iError.setReturnCode(rc);
+    QString message;
+    iArgument >> message;
+    iError.setMessage(message);
+    iArgument.endStructure();
+    return iArgument;
+}
+
+QScriptValue SKGErrorToScriptValue(QScriptEngine *engine, SKGError* const &in)
+{
+    return engine->newQObject(in);
+}
+
+void SKGErrorFromScriptValue(const QScriptValue &object, SKGError* &out)
+{
+    out = qobject_cast<SKGError*>(object.toQObject());
+}
+
 SKGError::SKGError()
-        :rc(0), message(""), previousError(NULL)
+    : QObject(), m_rc(0), m_message(""), m_previousError(NULL)
 {}
 
 SKGError::SKGError(int iRc, const QString& iMessage)
-        :rc(iRc), message(iMessage), previousError(NULL)
+    : QObject(), m_rc(iRc), m_message(iMessage), m_previousError(NULL)
 {}
 
 SKGError::SKGError(const SKGError& iError)
+    : QObject()
 {
-    rc = iError.rc;
-    message = iError.message;
-    if (iError.previousError != NULL) previousError = new SKGError(*iError.previousError);
-    else previousError = NULL;
+    m_rc = iError.m_rc;
+    m_message = iError.m_message;
+    if(iError.m_previousError != NULL) m_previousError = new SKGError(*iError.m_previousError);
+    else m_previousError = NULL;
 }
 
 SKGError::~SKGError()
 {
-    if (previousError) {
-        delete previousError;
-        previousError = NULL;
-    }
+    delete m_previousError;
+    m_previousError = NULL;
 }
 
-const SKGError& SKGError::operator= (const SKGError& iError)
+const SKGError& SKGError::operator= (const SKGError & iError)
 {
-    if (&iError!=this)
-    {
-        if (previousError) {
-            delete previousError;
-            previousError = NULL;
-        }
+    if(&iError != this) {
+        delete m_previousError;
+        m_previousError = NULL;
 
-        rc = iError.rc;
-        message = iError.message;
-        if (iError.previousError != NULL) previousError = new SKGError(*iError.previousError);
+        m_rc = iError.m_rc;
+        m_message = iError.m_message;
+        if(iError.m_previousError != NULL) m_previousError = new SKGError(*iError.m_previousError);
     }
     return *this;
 }
 
+bool SKGError::operator!() const
+{
+    return (m_rc <= 0);
+}
+
 bool SKGError::isFailed() const
 {
-    return (rc > 0);
+    return (m_rc > 0);
 }
 
 bool SKGError::isSucceeded() const
 {
-    return (rc <= 0);
+    return (m_rc <= 0);
 }
 
 bool SKGError::isWarning() const
 {
-    return (rc < 0);
+    return (m_rc < 0);
 }
 
 int SKGError::getReturnCode() const
 {
-    return rc;
+    return m_rc;
 }
 
 void SKGError::setReturnCode(int iReturnCode)
 {
-    rc = iReturnCode;
+    m_rc = iReturnCode;
 }
 
 void SKGError::setMessage(const QString & iMessage)
 {
-    message = iMessage;
+    m_message = iMessage;
 }
 
 QString SKGError::getMessage() const
 {
-    return message;
+    return m_message;
 }
 
 QString SKGError::getFullMessage() const
 {
     QString output('[');
-    output += (rc == 0 ? "SUC" : (rc > 0 ? "ERR" : "WAR"));
+    output += (m_rc == 0 ? "SUC" : (m_rc > 0 ? "ERR" : "WAR"));
     output += '-';
 
     QString tmp;
-    tmp.setNum(rc);
+    tmp.setNum(m_rc);
     output += tmp;
     output += ']';
-    if (message.length()) output += ": " + message;
+    if(!m_message.isEmpty()) output += ": " % m_message;
     return output;
 }
 
 QString SKGError::getFullMessageWithHistorical() const
 {
     QString output = getFullMessage();
-    if (previousError) output += '\n' + previousError->getFullMessageWithHistorical();
+    if(m_previousError) output += '\n' % m_previousError->getFullMessageWithHistorical();
     return output;
 }
 
 int SKGError::getHistoricalSize() const
 {
     int output = 0;
-    if (previousError) output += 1 + previousError->getHistoricalSize();
+    if(m_previousError) output += 1 + m_previousError->getHistoricalSize();
     return output;
 }
 
@@ -129,8 +160,8 @@ void SKGError::addError(int iRc, const QString & iMessage)
     SKGError* pe = new SKGError(*this);
     setReturnCode(iRc);
     setMessage(iMessage);
-    if (previousError) delete previousError;
-    previousError = pe;
+    delete m_previousError;
+    m_previousError = pe;
 }
 
 void SKGError::addError(const SKGError& iError)
@@ -140,6 +171,7 @@ void SKGError::addError(const SKGError& iError)
 
 SKGError* SKGError::getPreviousError() const
 {
-    return previousError;
+    return m_previousError;
 }
 
+#include "skgerror.moc"
