@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -35,15 +35,15 @@ class SKGBASEMODELER_EXPORT SKGNodeObject : public SKGNamedObject
     /**
      * Order of the node
      */
-    Q_PROPERTY( double order READ getOrder WRITE setOrder);
+    Q_PROPERTY(double order READ getOrder WRITE setOrder);
     /**
      * Full name of the node
      */
-    Q_PROPERTY( QString fullName READ getFullName);
+    Q_PROPERTY(QString fullName READ getFullName);
     /**
      * Data of the node
      */
-    Q_PROPERTY( QString data READ getData WRITE setData);
+    Q_PROPERTY(QString data READ getData WRITE setData);
 
 public:
 
@@ -57,7 +57,7 @@ public:
      * @param iDocument the document containing the object
      * @param iID the identifier in @p iTable of the object
      */
-    explicit SKGNodeObject(SKGDocument* iDocument=NULL, int iID=0);
+    explicit SKGNodeObject(SKGDocument* iDocument = NULL, int iID = 0);
 
     /**
      * Copy constructor
@@ -94,7 +94,7 @@ public:
     static SKGError createPathNode(SKGDocument* iDocument,
                                    const QString& iFullPath,
                                    SKGNodeObject& oNode,
-                                   bool iRenameIfAlreadyExist=false);
+                                   bool iRenameIfAlreadyExist = false);
 
     /**
      * Set the name of this object
@@ -186,6 +186,14 @@ public:
      */
     virtual bool isFolder() const;
 
+    /**
+     * Set icon of this node
+     * @param iIcon the icon name
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError setIcon(const QString& iIcon);
+
     /**
      * Get icon of this node
      * @return the icon
@@ -217,5 +225,5 @@ protected:
 /**
  * Declare the class
  */
-Q_DECLARE_TYPEINFO ( SKGNodeObject, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO(SKGNodeObject, Q_MOVABLE_TYPE);
 #endif
