@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -31,6 +31,8 @@
 
 class SKGDocument;
 class SKGPropertyObject;
+class SKGObjectBasePrivate;
+
 /**
  * This class is the base class for all objects.
  * This class is a generic way to manipulate objects.
@@ -44,15 +46,15 @@ class SKGBASEMODELER_EXPORT SKGObjectBase : public QObject
     /**
      * Unique ide  of the object
      */
-    Q_PROPERTY( QString uniqueID READ getUniqueID);
+    Q_PROPERTY(QString uniqueID READ getUniqueID);
     /**
      * Id of the object
      */
-    Q_PROPERTY( int ID READ getID);
+    Q_PROPERTY(int ID READ getID);
     /**
      * Table of the object
      */
-    Q_PROPERTY( QString table READ getTable);
+    Q_PROPERTY(QString table READ getTable);
 
 public:
     /**
@@ -65,65 +67,13 @@ public:
      */
     typedef QList<SKGObjectBase>::Iterator SKGListSKGObjectBaseIterator;
 
-    /**
-     * Return a number of objects (@p oNbObjects) corresponding to a where clause (@p iWhereClause )
-     * @param iDocument the document where to search
-     * @param iTable the table where to search
-     * @param iWhereClause the where clause
-     * @param oNbObjects the result
-     * @return an object managing the error
-     *   @see SKGError
-     */
-    static SKGError getNbObjects(SKGDocument* iDocument, const QString& iTable,
-                                 const QString& iWhereClause, int& oNbObjects);
-
-    /**
-     * Return a list of objects (@p oListObject) corresponding to a where clause (@p iWhereClause )
-     * @param iDocument the document where to search
-     * @param iTable the table where to search
-     * @param iWhereClause the where clause
-     * @param oListObject the result
-     * @return an object managing the error
-     *   @see SKGError
-     */
-    static SKGError getObjects(SKGDocument* iDocument, const QString& iTable,
-                               const QString& iWhereClause, SKGListSKGObjectBase& oListObject);
-
-    /**
-     * Return the object (@p oObject) corresponding to a where clause (@p iWhereClause ).
-     * If more than one objects are returned by the query, then an error is generated
-     * If 0 object is returned by the query, then an error is generated
-     * @param iDocument the document where to search
-     * @param iTable the table where to search
-     * @param iWhereClause the where clause
-     * @param oObject the result
-     * @return an object managing the error
-     *   @see SKGError
-     */
-    static SKGError getObject(SKGDocument* iDocument, const QString& iTable,
-                              const QString& iWhereClause, SKGObjectBase& oObject);
-
-    /**
-     * Return the object (@p oObject) corresponding to an id (@p iId ).
-     * If more than one objects are returned by the query, then an error is generated
-     * If 0 object is returned by the query, then an error is generated
-     * @param iDocument the document where to search
-     * @param iTable the table where to search
-     * @param iId id of the object in @p iTable
-     * @param oObject the result
-     * @return an object managing the error
-     *   @see SKGError
-     */
-    static SKGError getObject(SKGDocument* iDocument, const QString& iTable,
-                              int iId, SKGObjectBase& oObject);
-
     /**
      * Constructor
      * @param iDocument the document containing the object
      * @param iTable the table of the object
      * @param iID the identifier in @p iTable of the object
      */
-    explicit SKGObjectBase(SKGDocument* iDocument=NULL, const QString& iTable="", int iID=0);
+    explicit SKGObjectBase(SKGDocument* iDocument = NULL, const QString& iTable = "", int iID = 0);
 
     /**
      * Copy constructor
@@ -165,7 +115,7 @@ public:
      * Clone this object into a new document. The id is not kept. The cloned object is not saved into the target document->
      * @param iDocument the target document. If NULL then target document=source document->
      */
-    virtual SKGObjectBase cloneInto(SKGDocument* iDocument=NULL);
+    virtual SKGObjectBase cloneInto(SKGDocument* iDocument = NULL);
 
     /**
      * Destructor
@@ -284,7 +234,7 @@ public:
      * @return an object managing the property
      *   @see SKGError
      */
-    virtual SKGError setProperty(const QString& iName, const QString& iValue, const QString& iFileName, SKGPropertyObject* oObjectCreated=NULL) const;
+    virtual SKGError setProperty(const QString& iName, const QString& iValue, const QString& iFileName, SKGPropertyObject* oObjectCreated = NULL) const;
 
     /**
      * Set the value for a property
@@ -295,7 +245,7 @@ public:
      * @return an object managing the property
      *   @see SKGError
      */
-    virtual SKGError setProperty(const QString& iName, const QString& iValue, const QVariant& iBlob=QVariant(), SKGPropertyObject* oObjectCreated=NULL) const;
+    virtual SKGError setProperty(const QString& iName, const QString& iValue, const QVariant& iBlob = QVariant(), SKGPropertyObject* oObjectCreated = NULL) const;
 
     /**
      * To know if an object exists or not
@@ -319,15 +269,16 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError save(bool iInsertOrUpdate=true, bool iReloadAfterSave=true);
+    virtual SKGError save(bool iInsertOrUpdate = true, bool iReloadAfterSave = true);
 
     /**
      * delete the object into the database
      * @param iSendMessage to send message when the object is deleted
+     * @param iForce to force the deletion
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError remove(bool iSendMessage=true) const;
+    virtual SKGError remove(bool iSendMessage = true, bool iForce = false) const;
 
     /**
      * dump the object
@@ -351,28 +302,10 @@ protected:
     virtual QString getWhereclauseId() const;
 
 private:
-    /**
-     * internal id
-     */
-    int id;
-
-    /**
-     * internal table
-     */
-    QString table;
-
-    /**
-     * internal document
-     */
-    SKGDocument* document;
-
-    /**
-     * internal attributes
-     */
-    SKGQStringQStringMap attributes;
+    SKGObjectBasePrivate* const d;
 };
 /**
  * Declare the class
  */
-Q_DECLARE_TYPEINFO ( SKGObjectBase, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO(SKGObjectBase, Q_MOVABLE_TYPE);
 #endif
