@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,30 +23,30 @@
 #include "skgdocument.h"
 #include "skgerror.h"
 
-SKGTransactionMng::SKGTransactionMng(const SKGDocument* iDocument,
+SKGTransactionMng::SKGTransactionMng(SKGDocument* iDocument,
                                      const QString& iName,
                                      SKGError* iError,
                                      int iNbStep)
 {
-        parentDocument = (SKGDocument*) iDocument;
-        error = iError;
-        if (parentDocument && error) {
-                *error = parentDocument->beginTransaction(iName, iNbStep);
-                errorInBeginTransaction=(error->isFailed());
-        }
+    m_parentDocument = iDocument;
+    m_error = iError;
+    if(m_parentDocument && m_error) {
+        *m_error = m_parentDocument->beginTransaction(iName, iNbStep);
+        m_errorInBeginTransaction = (m_error->isFailed());
+    }
 
 }
 
 SKGTransactionMng::~SKGTransactionMng()
 {
-        if (parentDocument && error) {
-                //close the transaction based on error
-                if (!errorInBeginTransaction) {
-                        if (error->isSucceeded()) *error = parentDocument->endTransaction(true);
-                        else  parentDocument->endTransaction(false);
-                }
-                parentDocument=NULL;
-                error=NULL;
+    if(m_parentDocument && m_error) {
+        //close the transaction based on error
+        if(!m_errorInBeginTransaction) {
+            if(m_error->isSucceeded()) *m_error = m_parentDocument->endTransaction(true);
+            else  m_parentDocument->endTransaction(false);
         }
+        m_parentDocument = NULL;
+        m_error = NULL;
+    }
 }
 
