@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -37,7 +37,7 @@
  *   SKGBEGINTRANSACTION(Your_SKGDocument, "The_Name_Of_The_Transaction", err);
  *
  *  //Check the error
- *  if(err.isSucceeded())
+ *  if(!err)
  *  {
  *   //You code here
  *   //At the end the err variable must contain the result of your operation
@@ -63,7 +63,7 @@
  *   SKGBEGINPROGRESSTRANSACTION(Your_SKGDocument, "The_Name_Of_The_Transaction", err, 5);
  *
  *  //Check the error
- *  if(err.isSucceeded())
+ *  if(!err)
  *  {
  *   //You code here
  *   //At the end the err variable must contain the result of your operation
@@ -102,7 +102,7 @@ public:
      * It's used to call the progress callback.
      * @see The SKGError
      */
-    SKGTransactionMng(SKGDocument* iDocument, const QString& iName, SKGError* iError, int iNbStep=1);
+    SKGTransactionMng(SKGDocument* iDocument, const QString& iName, SKGError* iError, int iNbStep = 1);
 
     /**
      * Destructor
@@ -112,9 +112,9 @@ public:
 private:
     Q_DISABLE_COPY(SKGTransactionMng);
 
-    SKGError* error;
-    SKGDocument* parentDocument;
-    bool errorInBeginTransaction;
+    SKGError* m_error;
+    SKGDocument* m_parentDocument;
+    bool m_errorInBeginTransaction;
 };
 
 #endif
