@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -27,11 +27,6 @@
 #include <kcmdlineargs.h>
 #include <KDE/KLocale>
 
-/**
- * Description of the application
- */
-static const char description[] = I18N_NOOP("Personal finance management tool for KDE4, with the aim of being highly intuitive, while providing powerful functions such as reporting (including graphics), persistent Undo/Redo, encryption, and much more...");
-
 /**
  * To compute the version
  */
@@ -58,31 +53,46 @@ int main(int argc, char **argv)
                      0,
                      ki18nc("The name of the application", "Skrooge"),
                      VER,
-                     ki18nc("The description of the application", description),
+                     ki18nc("The description of the application", "Personal finance management tool for KDE4, with the aim of being highly intuitive, while providing powerful functions such as reporting (including graphics), persistent Undo/Redo, encryption, and much more..."),
                      KAboutData::License_GPL_V3,
-                     ki18nc("Fullname", "(c) 2007-2010 Stephane MANKOWSKI & Guillaume DE BURE"),
+                     ki18nc("Fullname", "(c) 2007-%1 Stephane MANKOWSKI & Guillaume DE BURE").subs(QDate::currentDate().toString("yyyy")),
                      KLocalizedString(),
                      "http://skrooge.org");
 
-    about.addAuthor( ki18nc("Fullname", "Stephane MANKOWSKI"), ki18nc("A job description", "Architect & Developer"), "stephane@mankowski.fr" );
-    about.addAuthor( ki18nc("Fullname", "Guillaume DE BURE"), ki18nc("A job description", "Developer"), "guillaume.debure@gmail.com" );
-    about.setOtherText( ki18nc("The description of the application", "The application name is inspired by Charles Dicken's tale <i>A Christmas Carol</i>, where the main character, Ebenezer Scrooge, a grumpy old narrow man, gets visited by three ghosts who change the way he sees the world, in a good way."));
+    about.addAuthor(ki18nc("Fullname", "Stephane MANKOWSKI"), ki18nc("A job description", "Architect & Developer"), "stephane@mankowski.fr", ""
+#ifdef SKGKDE46ENABLED
+                    , "miraks"
+#endif
+                   );
+    about.addAuthor(ki18nc("Fullname", "Guillaume DE BURE"), ki18nc("A job description", "Developer"), "guillaume.debure@gmail.com", ""
+#ifdef SKGKDE46ENABLED
+                    , "willy9"
+#endif
+                   );
+    about.setOtherText(ki18nc("The description of the application", "The application name is inspired by Charles Dicken's tale <i>A Christmas Carol</i>, where the main character, Ebenezer Scrooge, a grumpy old narrow man, gets visited by three ghosts who change the way he sees the world, in a good way."));
 
     KCmdLineArgs::init(argc, argv, &about);
 
     KCmdLineOptions options;
-    options.add("+[URL]", ki18nc("Application argument", "Document to open" ));
+    options.add("+[URL]", ki18nc("Application argument", "Document to open"));
     KCmdLineArgs::addCmdLineOptions(options);
 
-    int rc=0;
-    if (!SKGUniqueApplication::start()) {
+    int rc = 0;
+    bool started = false;
+    if(!SKGServices::getenv("SKGNOTUNIQUE").isEmpty()) {
+        started = SKGUniqueApplication::start(SKGUniqueApplication::NonUniqueInstance);
+    } else {
+        started = SKGUniqueApplication::start();
+    }
+    if(!started) {
         fprintf(stderr, "Skrooge is already running!\n");
     } else {
         //Creating a main panel on a bank document
         SKGDocumentBank doc;
-        SKGUniqueApplication kApp(&doc);
-
-        rc=kApp.exec(); // krazy:exclude=crashy
+        {
+            SKGUniqueApplication kApp(&doc);
+            rc = kApp.exec(); // krazy:exclude=crashy
+        }
     }
     SKGTraces::dumpProfilingStatistics();
     return rc;
